#### Exp 1: Analysis of behavioural data ####

# This experiment had 6 birds sharing two SFS units in a single room

# Written by Melissa Bateson


#remove any existing data/values in the global environment
rm(list=ls())


# load necessary packages
library(dplyr)
library(ggplot2)
library(psych)
library(lme4)
library(lmerTest)
library(tidyr)
library(PerformanceAnalytics)
library(metafor)



am = read.csv("Exp 1 behaviour data.csv")

am$date = as.Date(am$date)


# It is only valid to compare the am data between treatments because the pm data could be affected by the treatment in place:
# birds might forage more actively during periods of FI but still save energy across the day.
# therefore only analyse am data

describe(am)
# roost is the most common and most variable behaviour
# roost is also by definition always visible


#make a subset of just the behavioural variables
b = subset(am,select=c("fly", "bathe", "perch","slide","roost","sfs","walk"))
chart.Correlation(b)


# Do a PCA on the data
pca.b = prcomp(b, scale = TRUE)
names(pca.b)

pca.b$rotation
biplot(pca.b, scale = 0)
std_dev = pca.b$sdev
pr_var = std_dev^2
pr_var[1:7]

#proportion of variance explained
prop_varex = pr_var/sum(pr_var)
prop_varex[1:7]
# In this case the PC1 explaines 27% of the variance

#scree plot
plot(prop_varex, xlab = "Principal Component",
     ylab = "Proportion of Variance Explained",
     type = "b")

#cumulative scree plot
plot(cumsum(prop_varex), xlab = "Principal Component",
     ylab = "Cumulative Proportion of Variance Explained",
     type = "b")

dim(pca.b$x)

pca.out = as.data.frame(pca.b$x) # this is the PCA data

am$PC1 = pca.out$PC1


# Is PC1 explained by treatment yesterday?
m = lmer(PC1 ~ treatment.yesterday+ (1|room), data = am)
summary(m) 





# is being in shot explained by treatment?
m = lmer(in.shot ~ treatment.yesterday + (1|room), data = am)
summary(m) # birds are more likely to be in shot in FI and FS2 compared to FS1


am$active.prop = am$active/60
hist(am$active.prop)
# is active explained by treatment?
am$treatment.yesterday = relevel(am$treatment.yesterday, ref = "FS1")
m = lmer(active.prop ~ treatment.yesterday + (1|room), data = am)
summary(m) # birds are less likely to be active in FI and FS2




#### Roosing behaviour ####


am$roost.prop = am$roost/60
hist(am$roost.prop)

am$trans.roost = transf.arcsin(am$roost.prop) # implement the arcsin square root transformation on proportions
hist(am$trans.roost) # distribution is much more normal now

am$room.date = as.factor(paste(am$room, am$date)) # create a random effect to group data from the same day

# plot a graph of proportion roosting
# within-pair centering based on raw values for plotting
am$treatment.yesterday = relevel(am$treatment.yesterday, ref = "FS1")
mean.room = summarise(group_by(am, room), prop.roost.room = mean((roost.prop), na.rm=T))
am = merge(am,mean.room, by="room")
# within-pair centering followed by adding back the grand mean so that treatment effects are relocated relative to the grand mean
am$norm.roost = ((am$roost.prop) - am$prop.roost.room)+(mean((am$roost.prop), na.rm=T))

# Plot a graph of roosting by treatment (using all days)
fig = ggplot(data=am, aes(x=treatment.wk, y=norm.roost)) +
  geom_boxplot(aes(fill=treatment.wk)) +
  #geom_point() +
  scale_fill_manual(values=c("cyan", "tomato", "tomato", "cyan")) +
  ylab("Proportion roosting") +
  xlab("") +
  guides (fill = FALSE) +
  coord_cartesian(ylim = c(0,1.19)) +
  #ylim(0,1.1) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2.5, y=.94, yend=.94, size=.5) +
  annotate("text", x=1.75, y=.96, label = "NS", size=4) +
  annotate("segment", x=2.5, xend=4, y=1, yend=1, size=.5) +
  annotate("text", x=3.25, y=1.02, label = "***", size=4) +
  annotate("segment", x=1, xend=4, y=1.06, yend=1.06, size=.5) +
  annotate("text", x=2.5, y=1.08, label = "***", size=4)
fig
win.metafile("Exp 1 roosting.wmf")
fig
dev.off()


# model the data
am$treatment.yesterday = relevel(am$treatment.yesterday, ref = "FS1")
m = lmer(trans.roost ~ treatment.yesterday + (1|room/room.date), data = am)
summary(m)
anova(m)
confint(m)

am$treatment.yesterday = relevel(am$treatment.yesterday, ref = "FS2")
m2 = lmer(trans.roost ~ treatment.yesterday + (1|room/room.date), data = am)
summary(m2)
confint(m2)

mean.roost = summarise(group_by(am, treatment.yesterday), mean.roost = mean(roost.prop))

output.roost.all = data.frame("exp" = "Exp 1","aviary" = "all", "variable" = "prop.roost",
                              "mean.FS" = mean.roost$mean.roost[1],
                              "mean.FI" = mean.roost$mean.roost[2],
                              "beta" = coef(summary(m))["treatment.yesterdayFI", "Estimate"],
                              "se.beta" = coef(summary(m))["treatment.yesterdayFI", "Std. Error"])


# analysis by aviary

# Now calculate the effects of FI on consumption by aviary for the by aviary meta-analysis
am$treatment.yesterday = relevel(am$treatment.yesterday, ref = "FS1")
# room 114
am.114 = am[am$room=="114", ]
m.114 = lmer(trans.roost ~ treatment.yesterday + (1|room.date), data=am.114)
summary(m.114)

mean.roost.114 = summarise(group_by(am.114, treatment.yesterday), mean.roost = mean(roost.prop))

output.roost.114 = data.frame("exp" = "Exp 1","aviary" = "114", "variable" = "prop.roost",
                              "mean.FS" = mean.roost.114$mean.roost[1],
                              "mean.FI" = mean.roost.114$mean.roost[3],
                              "beta" = coef(summary(m.114))["treatment.yesterdayFI", "Estimate"],
                              "se.beta" = coef(summary(m.114))["treatment.yesterdayFI", "Std. Error"])

# room 115
am.115 = am[am$room=="115", ]
m.115 = lmer(trans.roost ~ treatment.yesterday + (1|room.date), data=am.115)
summary(m.115)

mean.roost.115 = summarise(group_by(am.115, treatment.yesterday), mean.roost = mean(roost.prop))

output.roost.115 = data.frame("exp" = "Exp 1","aviary" = "115", "variable" = "prop.roost",
                              "mean.FS" = mean.roost.115$mean.roost[1],
                              "mean.FI" = mean.roost.115$mean.roost[3],
                              "beta" = coef(summary(m.115))["treatment.yesterdayFI", "Estimate"],
                              "se.beta" = coef(summary(m.115))["treatment.yesterdayFI", "Std. Error"])

# room 116
am.116 = am[am$room=="116", ]
m.116 = lmer(trans.roost ~ treatment.yesterday + (1|room.date), data=am.116)
summary(m.116)

mean.roost.116 = summarise(group_by(am.116, treatment.yesterday), mean.roost = mean(roost.prop))

output.roost.116 = data.frame("exp" = "Exp 1","aviary" = "116", "variable" = "prop.roost",
                              "mean.FS" = mean.roost.116$mean.roost[1],
                              "mean.FI" = mean.roost.116$mean.roost[3],
                              "beta" = coef(summary(m.116))["treatment.yesterdayFI", "Estimate"],
                              "se.beta" = coef(summary(m.116))["treatment.yesterdayFI", "Std. Error"])


# output the meta-data for roosting

output = rbind(output.roost.114,output.roost.115,output.roost.116)

write.csv(output,"Exp 1 roosting data for meta-analysis.csv")
write.csv(output.roost.all,"Exp 1 roosting data for meta-analysis all.csv")



