#### Exp 1: Analysis of food eaten and masses ####

# This experiment had 6 birds housed in 3 pairs each sharing a single SFS unit

# Written by Melissa Bateson


#remove any existing data/values in the global environment
rm(list=ls())


# load necessary packages
library(dplyr)
library(ggplot2)
library(reshape2)
library(lubridate)
library(psych)
library(lme4)
library(lmerTest)
library(tidyr)


#### Define some useful functions ####

# function to turn hr:min:sec to minutes since midnight as a decimal
decimateTime=function(time) {
  time=as.numeric(unlist(strsplit(time, ":")))
  time = time[1]*60+time[2]+time[3]/60
  return(time)
}

#create a new version of length which can handle NA's: if na.rm==T, don't count them
length2 <- function (x, na.rm=FALSE) {
  if (na.rm) sum(!is.na(x))
  else       length(x)
}



#### Anaysis of daily food consumption #### 

food = read.csv("Exp 1 food consumption data.csv")

food$date = as.POSIXct(food$date)



food$HWeightStart = NULL
food$HWeightEnd = NULL
food$phase = NULL
food$day.exp = food$day.expt-9

food$day.expt = NULL


# code the phases of the experiment
# Stabilisation: 13/03-21/03
# Food.security.1: 22/03-28/03
# Food.insecurity: 29/03-11/04
# Food.security.2: 12/04-18-04

food$treatment[food$date<"2019-03-22"]="stabilisation"
food$treatment[food$date>"2019-03-21"&food$date<"2019-03-29"]="FS1"
food$treatment[food$date>"2019-03-28"&food$date<"2019-04-12"]="FI"
food$treatment[food$date>"2019-04-11"&food$date<"2019-04-19"]="FS2"

f1 = food[food$treatment!="stabilisation",]
f1$total.eaten= f1$food_g

f1$room = as.factor(f1$room)

f1$treatment = as.factor(f1$treatment)
f1$treatment = relevel(f1$treatment, ref = "FS1") # change ref level to get phases in the right order

# create a 'day.treat' variable to indicate the day of each treatment and merge it into the main dataframe
d.date= unique(subset(f1,select=c("date","treatment")))
d.date = d.date%>%
  group_by(treatment)%>%
  mutate(day.treat=seq_along(date))
d.date= subset(d.date,select=c("date","day.treat"))
f1 = merge(f1,d.date, by = "date")

f1$treatment.wk[f1$treatment=="FS1"] = "FS1"
f1$treatment.wk[f1$treatment=="FS2"] = "FS2"
f1$treatment.wk[f1$treatment=="FI"&f1$day.treat<8] = "FIa"
f1$treatment.wk[f1$treatment=="FI"&f1$day.treat>7] = "FIb"
f1$treatment.wk = factor(f1$treatment.wk, levels = c("FS1","FIa","FIb","FS2"))




# Basic stats per bird
mean.eaten.room = summarise(group_by(f1, treatment, room), mean.eaten = mean(total.eaten/2))

mean.eaten = summarise(group_by(mean.eaten.room, treatment), mean.eaten.bird = mean(mean.eaten), 
                            sd.food.eaten = sd(mean.eaten), n.food.eaten = length(mean.eaten))


# within-pair centering based on raw values for plotting
mean.room = summarise(group_by(f1, room), mean.food.room = mean((total.eaten/2), na.rm=T))
f1 = merge(f1,mean.room, by="room")
# within-pair centering followed by adding back the grand mean so that treatment effects are relocated relative to the grand mean
f1$norm.eaten = ((f1$total.eaten/2) - f1$mean.food.room)+(mean((f1$total.eaten), na.rm=T)/2)
f1$norm.eaten = ((f1$total.eaten/2) - f1$mean.food.room)+mean(mean.eaten$mean.eaten.bird)

# Plot a graph of consumption by treatment (using all days)
fig = ggplot(data=f1, aes(x=treatment.wk, y=norm.eaten)) +
  geom_boxplot(aes(fill=treatment.wk)) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato", "cyan")) +
  ylab("Food consumption (g/day)") +
  xlab("") +
  guides (fill = FALSE) +
  ylim(9,22) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2.5, y=20, yend=20, size=.5) +
  annotate("text", x=1.75, y=20.2, label = "***", size=4) +
  annotate("segment", x=2.5, xend=4, y=19, yend=19, size=.5) +
  annotate("text", x=3.25, y=19.2, label = "NS", size=4) +
  annotate("segment", x=1, xend=4, y=21, yend=21, size=.5) +
  annotate("text", x=2.5, y=21.2, label = "***", size=4)
fig
win.metafile("Exp 1 consumption.wmf")
fig
dev.off()

# Model amount eaten
f1$treatment = relevel(f1$treatment, ref = "FS1")
m = lmer((total.eaten/2) ~ treatment + (1|room), data = f1)
summary(m) # The birds eat significantly less under FI and this is maintained under FS2
confint(m)
anova(m)
# Run the model again with scaled data to get standardised effect size
f1$treatment = relevel(f1$treatment, ref = "FS1")
m2 = lmer(scale(total.eaten/2) ~ treatment + (1|room), data = f1)
summary(m2) # The birds eat significantly less under FI and this is maintained under FS2

f1$treatment = relevel(f1$treatment, ref = "FS2") # change ref level to get comparison of FI and FS2
m1 = lmer((total.eaten/2) ~ treatment + (1|room), data = f1)
summary(m1) # No difference between FI and FS2
confint(m1)



# output the meta-data
output.food = data.frame("exp" = "Exp 1","aviary" = "all", "variable" = "food.eaten",
                         "mean.FS" = mean.eaten$mean.eaten[1],
                         "mean.FI" = mean.eaten$mean.eaten[2],
                         "beta" = coef(summary(m))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m))["treatmentFI", "Std. Error"],
                         "standard.beta" = coef(summary(m2))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatmentFI", "Std. Error"])



# Now calculate the effects of FI on consumption by aviary for the by aviary meta-analysis
# room 114
f1$treatment = relevel(f1$treatment, ref = "FS1")
f1.114 = f1[f1$room=="114", ]
m.114 = lm(total.eaten/2 ~ treatment, data=f1.114)
summary(m.114)
m2.114 = lm(scale(total.eaten/2) ~ treatment, data=f1.114) # for standardised beta
summary(m2.114)

output.eaten.114 = data.frame("exp" = "Exp 1","aviary" = "114", "variable" = "food.eaten",
                              "mean.FS" = mean.eaten.room$mean.eaten[1],
                              "mean.FI" = mean.eaten.room$mean.eaten[4],
                              "beta" = coef(summary(m.114))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m.114))["treatmentFI", "Std. Error"],
                              "standard.beta" = coef(summary(m2.114))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2.114))["treatmentFI", "Std. Error"])

# room 115
f1.115 = f1[f1$room=="115", ]
m.115 = lm(total.eaten/2 ~ treatment, data=f1.115)
summary(m.115)
m2.115 = lm(scale(total.eaten/2) ~ treatment, data=f1.115) # for standardised beta
summary(m2.115)

output.eaten.115 = data.frame("exp" = "Exp 1","aviary" = "115", "variable" = "food.eaten",
                              "mean.FS" = mean.eaten.room$mean.eaten[2],
                              "mean.FI" = mean.eaten.room$mean.eaten[5],
                              "beta" = coef(summary(m.115))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m.115))["treatmentFI", "Std. Error"],
                              "standard.beta" = coef(summary(m2.115))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2.115))["treatmentFI", "Std. Error"])
# room 116
f1.116 = f1[f1$room=="116", ]
m.116 = lm(total.eaten/2 ~ treatment, data=f1.116)
summary(m.116)
m2.116 = lm(scale(total.eaten/2) ~ treatment, data=f1.116) # for standardised beta
summary(m2.116)

output.eaten.116 = data.frame("exp" = "Exp 1","aviary" = "116", "variable" = "food.eaten",
                              "mean.FS" = mean.eaten.room$mean.eaten[3],
                              "mean.FI" = mean.eaten.room$mean.eaten[6],
                              "beta" = coef(summary(m.116))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m.116))["treatmentFI", "Std. Error"],
                              "standard.beta" = coef(summary(m2.116))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2.116))["treatmentFI", "Std. Error"])



#### Mass data ####

#read in the mass data 
mass = read.csv("Exp 1 mass data.csv",sep=" ",header=F)
colnames(mass) = c("date","time","balance","RFID","mass_kg")
#check for blank rows
sapply(mass, function(x) sum(is.na(x))) # none
# d.na = mass[is.na(mass$RFID)==TRUE,] # if present, examine these rows and clean the dataset

xtabs(~mass$RFID) # check RFIDs present in the file to make sure these are all in the rfid file

# read in the RFID file
tag=read.delim("rfids.txt", header=T)
tag$room = tag$Room
tag$Room = NULL

# merge the two files to incorporate bird IDs into mass dataframe
d=merge(tag, mass, by="RFID", all.y=F)
head(d)


d$bird = d$Bird
d$Bird = NULL



xtabs(~d$bird)

# sort out the data types
d$RFID = as.factor(d$RFID)
#convert mass in kg to mass in g
d$mass_g = d$mass_kg*1000

#now want to get the times/dates in a usable format
#create a datetime variable (useful if you need to plot both date and time on the x axis)
d$date_time = ymd_hms(paste(d$date, d$time))

#create a time only variable
d$time.only = strptime(d$time, format = "%H:%M:%S")

#bin mass events by 1h
d$bin.1h = as.numeric(format(d$date_time,"%H"))

# convert times and dates to correct data type
d$time.only = as.POSIXct(d$time.only)
d$date = as.POSIXct(d$date)

# create a decimal time variable (minutes since midnight)
d$time.dec = as.character(d$time)
d$time.dec = (as.numeric(as.POSIXct(paste("2014-01-01", d$time.dec))) - 
                as.numeric(as.POSIXct("2014-01-01 0:0:0")))/60 # this code converts h:m:s to decimal minutes from midnight

# sort the dataset by date and time
d=d[order(d$date_time), ]



# code the phases of the experiment
# Stabilisation: 13/03-21/03
# Food.security.1: 22/03-28/03
# Food.insecurity: 29/03-11/04
# Food.security.2: 12/04-18-04

d$treatment[d$date<"2019-03-22"]="stabilisation"
d$treatment[d$date>"2019-03-21"&d$date<"2019-03-29"]="FS1"
d$treatment[d$date>"2019-03-28"&d$date<"2019-04-12"]="FI"
d$treatment[d$date>"2019-04-11"&d$date<"2019-04-19"]="FS2"
d$treatment = factor(d$treatment, levels = c("FS1", "FI", "FS2"))


# create a subset of the data that only contains the experimental phases
d1 = d[d$date>"2019-03-21",]
# remove data from test mass
d1 = d1[d1$bird!="test",]
xtabs(~d1$bird)
d1$bird = droplevels(d1$bird)
levels(d1$bird)

# exclude masses collected before 0900 and after 1800
d1 = d1[(d1$time.dec>=540),]
d1 = d1[(d1$time.dec<1080),]
max(d1$time.only)
min(d1$time.only)

#Create a 'day' variable to indicate the day of each phase and merge it into the main dataframe
d.date= unique(subset(d1,select=c("date","treatment")))
d.date = d.date%>%
  group_by(treatment)%>%
  mutate(day.treat=seq_along(date))
d.date= subset(d.date,select=c("date","day.treat"))
d.date$day.exp = seq(1:28)
d1 = merge(d1,d.date, by = "date")


# create a unique column with a unique row number (to be used later when remerging dataframes)
d1$row.number = seq(1,length(d1$date))


no.masses = summarise(group_by(d1,bird), n = length2(mass_g, na.rm = TRUE))
mean(no.masses$n)/28 # mean number of masses/bird/day = 31.99
mean(no.masses$n)/(28*9) # mean number of masses/bird/hr = 3.55


#### Polynomial fitting ####

# The aim of this part of the script is to fit the mass data obtained for each individual bird on each day of the experiment.
# The reason for this is to obtain a model of the mass change over the day that eliminates the noise in the measurements.
# We can then use the fitted values from the model in subsequent analyses (e.g. the maximum fitted mass in a day; the fitted mass at 1800 hrs)

# set the mass band either side of the fitted function for retaining masses
# I have finally settled on quite a high value that only excludes very extreme masses.
g.filter = 3

# make a new data frame to accumulate cleaned and fitted masses in
d.clean = data.frame(time.dec = numeric(0),time_s.clean = numeric(0), mass_g.clean= numeric(0), m.fit = numeric(0))
#make empty vectors for results
room = NULL
bird = NULL
treatment = NULL
day.treat = NULL
no.masses = NULL
no.masses.clean = NULL 
linear.p = NULL
quadratic.p = NULL
cubic.p = NULL
r_sq.fit = NULL
AIC.fit = NULL
mass.earliest = NULL
mass.latest = NULL
mass.max = NULL
mass.min = NULL
mass.9 = NULL
mass.10 = NULL
mass.11 = NULL
mass.12 = NULL
mass.13 = NULL
mass.14 = NULL
mass.15 = NULL
mass.16 = NULL
mass.17 = NULL
mass.18 = NULL
time.max.mass = NULL
time.min.mass = NULL
time.earliest.mass = NULL
time.latest.mass = NULL

row = 1

for(i in c("GGGG",  "P17GG", "P13GG", "P27GG", "P22GG", "P25GG")){ print(i)
  for(j in c("FS1","FI", "FS2")){ print(j)
    
    if (j=="FI")   {no.days= 14} 
    if (j=="FS1"|j =="FS2")   {no.days= 7}
    
    for(k in 1:no.days){ print(k)

bird[row] = i
treatment[row] = j
day.treat[row] = k

s = subset(d1, (bird == i & treatment == j & day.treat == k))

# stuff that goes inside the function

room[row] = as.character(s$room[1])

no.masses[row] = length(s$mass_g) # save the number of masses that day

# check to see that there is enough data to do the fitting
# 'degree' must be less than number of unique points; need degree+1 points for fit that is not just the data
# don't fit the data if there are no masses before 1100

if ((length(s$mass_g)<10)|(min(s$time.dec)>660)) {
  # Set fit parameters to NA
  linear.p[row] = NA
  quadratic.p[row] = NA
  cubic.p[row] = NA
  r_sq.fit[row] = NA
  AIC.fit[row] = NA
  mass.earliest[row] = NA
  mass.latest[row] = NA
  mass.max[row] = NA
  mass.min[row] = NA
  mass.9[row] = NA
  mass.10[row] = NA
  mass.11[row] = NA
  mass.12[row] = NA
  mass.13[row] = NA
  mass.14[row] = NA
  mass.15[row] = NA
  mass.16[row] = NA
  mass.17[row] = NA
  mass.18[row] = NA
  time.max.mass[row] = NA
  time.min.mass[row] = NA
  time.earliest.mass[row] = NA
  time.latest.mass[row] = NA
  
  row = row + 1
  }

  if ((length(s$mass_g) >=10)&(min(s$time.dec)<=660)) {

  m = lm(mass_g ~ poly(time.dec,degree=3), data = s) # NB this fits a cubic orthogonal polynomial

  s$m.fit.raw = predict(m)

  # calculate a fixed mass band for inclusion either side of the fitted slope
  s$m.lb=(s$m.fit.raw - g.filter)
  s$m.ub=(s$m.fit.raw + g.filter)
  # filter out any data outside these bounds
  s1 = subset(s, (mass_g<(m.fit.raw+g.filter) & mass_g>(m.fit.raw-g.filter)))
  s1$mass_g.clean = s1$mass_g
  s1$time_s.clean = s1$time.dec
  
  no.masses.clean[row] = length(s1$mass_g.clean) # save the number of masses retained in the final cleaned dataset
  
  # check to see that there is enough data to do the fitting
  # 'degree' must be less than number of unique points; need degree+1 points for fit that is not just the data
  # don't fit the data if there are no masses before 1100
  
  if ((length(s1$mass_g.clean)<10)|(min(s1$time.dec)>660)) {
    # Set fit parameters to NA
    linear.p[row] = NA
    quadratic.p[row] = NA
    cubic.p[row] = NA
    r_sq.fit[row] = NA
    AIC.fit[row] = NA
    mass.earliest[row] = NA
    mass.latest[row] = NA
    mass.max[row] = NA
    mass.min[row] = NA
    mass.9[row] = NA
    mass.10[row] = NA
    mass.11[row] = NA
    mass.12[row] = NA
    mass.13[row] = NA
    mass.14[row] = NA
    mass.15[row] = NA
    mass.16[row] = NA
    mass.17[row] = NA
    mass.18[row] = NA
    time.max.mass[row] = NA
    time.min.mass[row] = NA
    time.earliest.mass[row] = NA
    time.latest.mass[row] = NA
    
    row = row + 1
  }
  
  if ((length(s1$mass_g.clean) >=10)&(min(s1$time.dec)<=660)) {
    

  # refit the cleaned dataset
  m1 = lm(mass_g.clean ~ poly(time_s.clean,degree=3), data = s1, na.action = na.exclude) 
  s1$m.fit = predict(m1) # save the fitted values from the curve fitting

  # extract p-values from the fit
  linear.p[row] = summary(m1)$coefficients[2,4] # p-value for the linear term in the orthogonal fit
  quadratic.p[row] = summary(m1)$coefficients[3,4] # p-value for the quadratic term in the orthogonal fit
  cubic.p[row] = summary(m1)$coefficients[4,4] # p-value for the cubic term in the orthogonal fit

  # NB need to fit non-orthogonal polynomial to get the correct coefficients for the fitted line
  m2 = lm(mass_g.clean ~ time_s.clean + I(time_s.clean^2) + I(time_s.clean^3), data = s1, na.action = na.exclude)
  # eqn for cubic: y = a + bx + cx^2 + dx^3 where x is the minutes since midnight
  # extract parameter estimates b, c and d
  par.a = as.numeric(m2$coefficients[1])
  par.b = as.numeric(m2$coefficients[2])
  par.c = as.numeric(m2$coefficients[3])
  par.d = as.numeric(m2$coefficients[4])

  # calculate the fitted mass at each hour by plugging the relevant times into the fitted funtion
  mass.9[row] = par.a + (par.b*540) + (par.c*(540^2)) + (par.d*(540^3))
  mass.10[row] = par.a + (par.b*600) + (par.c*(600^2)) + (par.d*(600^3))
  mass.11[row] = par.a + (par.b*660) + (par.c*(660^2)) + (par.d*(660^3))
  mass.12[row] = par.a + (par.b*720) + (par.c*(720^2)) + (par.d*(720^3))
  mass.13[row] = par.a + (par.b*780) + (par.c*(780^2)) + (par.d*(780^3))
  mass.14[row] = par.a + (par.b*840) + (par.c*(840^2)) + (par.d*(840^3))
  mass.15[row] = par.a + (par.b*900) + (par.c*(900^2)) + (par.d*(900^3))
  mass.16[row] = par.a + (par.b*960) + (par.c*(960^2)) + (par.d*(960^3))
  mass.17[row] = par.a + (par.b*1020) + (par.c*(1020^2)) + (par.d*(1020^3))
  mass.18[row] = par.a + (par.b*1080) + (par.c*(1080^2)) + (par.d*(1080^3))

  # Extract parameters from the fit
  r_sq.fit[row] = summary(m1)$r.squared # r-squared for the fit
  AIC.fit[row] = AIC(m1) # AIC for the fit
  mass.earliest[row] = s1$m.fit[which(s1$time_s.clean==min(s1$time_s.clean))] # the earliest fitted mass
  mass.latest[row] = s1$m.fit[which(s1$time_s.clean==max(s1$time_s.clean))] # the latest fitted mass
  mass.max[row] = max(s1$m.fit) # the maximumn fitted mass
  mass.min[row] = min(s1$m.fit) # the minimum fitted mass
  time.max.mass[row] = median(s1$time_s.clean[which(s1$m.fit==max(s1$m.fit))]) # finds the time with the max value (median if more than one)
  time.min.mass[row] = median(s1$time_s.clean[which(s1$m.fit==min(s1$m.fit))]) # finds the time with the min value (median if more than one)
  time.earliest.mass[row] = min(s1$time_s.clean) # the time at which the first fitted mass occurred
  time.latest.mass[row] = max(s1$time_s.clean) # the time at which the last fitted mass occurred
  
  # we need a rule to exclude any fits when the latest mass that day is substantially before the time of the fit. 
  # Exclude any fits for which the latest mass that day is more than one hour previously.
  if (time.latest.mass[row] < 600) {mass.11[row]=NA}
  if (time.latest.mass[row] < 660) {mass.12[row]=NA}
  if (time.latest.mass[row] < 720) {mass.13[row]=NA}
  if (time.latest.mass[row] < 780) {mass.14[row]=NA}
  if (time.latest.mass[row] < 840) {mass.15[row]=NA}
  if (time.latest.mass[row] < 900) {mass.16[row]=NA}
  if (time.latest.mass[row] < 960) {mass.17[row]=NA}
  if (time.latest.mass[row] < 1020) {mass.18[row]=NA}

  row = row + 1
  

  s1 = subset(s1, select = c("row.number","time_s.clean","mass_g.clean","m.fit"))
  d.clean = rbind.data.frame(d.clean, s1)
  }

}

    }
  }
}

d.new = merge(d1,d.clean, by = "row.number", all.x = FALSE, all.y = TRUE)

fit.results = data.frame(room, bird, treatment, day.treat, no.masses,no.masses.clean, linear.p, quadratic.p, cubic.p, r_sq.fit, AIC.fit, mass.earliest, 
                         mass.latest, mass.max, mass.min,
                         mass.9, mass.10, mass.11, mass.12, mass.13, mass.14, mass.15, mass.16, mass.17, mass.18,
                         time.max.mass, time.min.mass, time.earliest.mass, time.latest.mass)


# create a column with the day of the experiment
fit.results$day.exp = rep(seq(1,28),6)

write.csv(fit.results, "Exp1_fit_results.csv")


# clean up the dataframe d.new
d.new$mass_g.fit = d.new$m.fit
d.new$m.fit = NULL

write.csv(d.new, "Exp1_mass_data_fitted_and_cleaned.csv")

describe(fit.results)



#### Fit some models to the fitted mass data ####

fit.results$treatment = factor(fit.results$treatment, levels = c("FS1","FI","FS2"))

# create a new column that splits the data by week
fit.results$treatment.wk[fit.results$treatment=="FS1"] = "FS1"
fit.results$treatment.wk[fit.results$treatment=="FS2"] = "FS2"
fit.results$treatment.wk[fit.results$treatment=="FI"&fit.results$day.treat<8] = "FIa"
fit.results$treatment.wk[fit.results$treatment=="FI"&fit.results$day.treat>7] = "FIb"
fit.results$treatment.wk = factor(fit.results$treatment.wk, levels = c("FS1","FIa","FIb","FS2"))

# calculate mean baseline dawn mass for each aviary and FI dawn mass
fit.results$aviary = fit.results$room
baseline = fit.results[fit.results$treatment=="FS1",]
baseline.mass = summarise(group_by(baseline, aviary), baseline.mass = mean(mass.9, na.rm = TRUE))

FI = fit.results[fit.results$treatment=="FI",]
FI.mass = summarise(group_by(FI, aviary), FI.mass = mean(mass.9, na.rm = TRUE))


fit.results = merge(fit.results, baseline.mass, by = "aviary")

# dawn mass (mean of fitted mass at 0900)
# first create a variable for treatment yesterday
treatment.yesterday = fit.results$treatment
treatment.yesterday = as.character(treatment.yesterday[1:length(treatment.yesterday)-1])
treatment.yesterday = c(NA, treatment.yesterday)
fit.results$treatment.yesterday = as.factor(treatment.yesterday)
fit.results$treatment.yesterday[fit.results$day.exp==1] = NA
fit.results$treatment.yesterday = relevel(fit.results$treatment.yesterday, ref = "FS1")

# and split this into weeks
fit.results$treatment.wk.yesterday[fit.results$treatment.yesterday=="FS1"] = "FS1"
fit.results$treatment.wk.yesterday[fit.results$treatment.yesterday=="FI"&fit.results$day.exp>8] = "FIa"
fit.results$treatment.wk.yesterday[fit.results$treatment.yesterday=="FI"&fit.results$day.exp>15] = "FIb"
fit.results$treatment.wk.yesterday[fit.results$treatment.yesterday=="FS2"] = "FS2"
fit.results$treatment.wk.yesterday = factor(fit.results$treatment.wk.yesterday, levels = c("FS1","FIa","FIb","FS2"))


# now plot the data splitting FS2 into two bars
# first get the means for each bird in each treatment
fit.results2=fit.results[is.na(fit.results$treatment.wk.yesterday)==FALSE,]
mean.fit.mass = summarise(group_by(fit.results2,bird,treatment.yesterday, treatment.wk.yesterday), Mean_mass = mean(mass.9, na.rm = TRUE))

#calculate mean mass for each treatment
mass.treat = summarise(group_by(mean.fit.mass, treatment.yesterday), mean.mass = mean(Mean_mass), sd.mass = sd(Mean_mass), n.mass = length2(Mean_mass))

# now calculate overall mean for each bird and merge this back into the dataframe
mean.mean.mass = summarise(group_by(mean.fit.mass, bird), Mean_mass_bird = mean(Mean_mass))
mean.fit.mass = merge(mean.fit.mass,mean.mean.mass, by="bird")
# within-subject centering followed by adding back the grant mean so that phase effects are relocated relative to the grand mean
mean.fit.mass$norm.mass = (mean.fit.mass$Mean_mass - mean.fit.mass$Mean_mass_bird)+mean(mean.fit.mass$Mean_mass_bird)

fig = ggplot(data=mean.fit.mass, aes(x=treatment.wk.yesterday, y=norm.mass)) +
  geom_boxplot(aes(fill=treatment.wk.yesterday)) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato", "cyan")) +
  guides(fill=FALSE) +
  ylab("Dawn mass (g)") +
  xlab("") +
  ylim(72.5,82.5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2.5, y=81, yend=81, size=.5) +
  annotate("text", x=1.75, y=81.25, label = "NS", size=4) +
  annotate("segment", x=2.5, xend=4, y=81.5, yend=81.5, size=.5) +
  annotate("text", x=3.25, y=81.75, label = "NS", size=4) +
  annotate("segment", x=1, xend=4, y=82, yend=82, size=.5) +
  annotate("text", x=2.5, y=82.25, label = "NS", size=4)
fig
win.metafile("Exp 1 dawn mass.wmf")
fig
dev.off()


fit.results$treatment.yesterday = relevel(fit.results$treatment.yesterday, ref = "FS1")
m = lmer(mass.9 ~ treatment.yesterday + (1|room/bird), data=fit.results)
summary(m)
confint(m)
anova(m) # No effect of treatment on dawn mass

fit.results$treatment.yesterday = relevel(fit.results$treatment.yesterday, ref = "FS2")
m1 = lmer(mass.9 ~ treatment.yesterday + (1|room/bird), data=fit.results)
summary(m1)
confint(m1)

# refit the above model with standardised data
fit.results$treatment.yesterday = relevel(fit.results$treatment.yesterday, ref = "FS1")
m2 = lmer(scale(mass.9) ~ treatment.yesterday + (1|room/bird), data=fit.results)
summary(m2)

# output the meta-data
output.dawn = data.frame("exp" = "Exp 1","aviary" = "all", "variable" = "mass.dawn",
                         "mean.FS" = mass.treat$mean.mass[1],
                         "mean.FI" = mass.treat$mean.mass[2],
                         "beta" = coef(summary(m))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m))["treatment.yesterdayFI", "Std. Error"],
                         "standard.beta" = coef(summary(m2))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatment.yesterdayFI", "Std. Error"])


# Now calculate the effects of FI on dawn mass by aviary
# room 114
fit.results$treatment.yesterday = relevel(fit.results$treatment.yesterday, ref = "FS1")
fit.results.114 = fit.results[fit.results$room=="114", ]
m.114 = lmer(mass.9 ~ treatment.yesterday + (1|bird), data=fit.results.114)
summary(m.114)
m2.114 = lmer(scale(mass.9) ~ treatment.yesterday + (1|bird), data=fit.results.114)
summary(m2.114)

output.dawn.114 = data.frame("exp" = "Exp 1","aviary" = "114", "variable" = "mass.dawn",
                              "mean.FS" = baseline.mass$baseline.mass[1],
                              "mean.FI" = FI.mass$FI.mass[1],
                              "beta" = coef(summary(m.114))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m.114))["treatment.yesterdayFI", "Std. Error"],
                              "standard.beta" = coef(summary(m2.114))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2.114))["treatment.yesterdayFI", "Std. Error"])

# room 115
fit.results.115 = fit.results[fit.results$room=="115", ]
m.115 = lmer(mass.9 ~ treatment.yesterday + (1|bird), data=fit.results.115)
summary(m.115)
m2.115 = lmer(scale(mass.9) ~ treatment.yesterday + (1|bird), data=fit.results.115)
summary(m2.115)

output.dawn.115 = data.frame("exp" = "Exp 1","aviary" = "115", "variable" = "mass.dawn",
                             "mean.FS" = baseline.mass$baseline.mass[2],
                             "mean.FI" = FI.mass$FI.mass[2],
                             "beta" = coef(summary(m.115))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m.115))["treatment.yesterdayFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2.115))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2.115))["treatment.yesterdayFI", "Std. Error"])

# room 116
fit.results.116 = fit.results[fit.results$room=="116", ]
m.116 = lmer(mass.9 ~ treatment.yesterday + (1|bird), data=fit.results.116)
summary(m.116)
m2.116 = lmer(scale(mass.9) ~ treatment.yesterday + (1|bird), data=fit.results.116)
summary(m2.116)

output.dawn.116 = data.frame("exp" = "Exp 1","aviary" = "116", "variable" = "mass.dawn",
                             "mean.FS" = baseline.mass$baseline.mass[3],
                             "mean.FI" = FI.mass$FI.mass[3],
                             "beta" = coef(summary(m.116))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m.116))["treatment.yesterdayFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2.116))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2.116))["treatment.yesterdayFI", "Std. Error"])




# dusk mass (mean of fitted mass at 1800)

# basic stats by aviary
mean.fit.mass.room = summarise(group_by(fit.results,treatment, room), mean.mass = mean(mass.18, na.rm = TRUE))

# now plot the data splitting FI into two bars
# first get the means for each bird in each treatment
mean.fit.mass = summarise(group_by(fit.results,bird,treatment, treatment.wk), Mean_mass = mean(mass.18, na.rm = TRUE))

#calculate mean mass for each treatment
mass.treat = summarise(group_by(mean.fit.mass, treatment), mean.mass = mean(Mean_mass), sd.mass = sd(Mean_mass), n.mass = length2(Mean_mass))
# now calculate overall mean for each bird and merge this back into the dataframe
mean.mean.mass = summarise(group_by(mean.fit.mass, bird), Mean_mass_bird = mean(Mean_mass))
mean.fit.mass = merge(mean.fit.mass,mean.mean.mass, by="bird")
# within-subject centering followed by adding back the grant mean so that phase effects are relocated relative to the grand mean
mean.fit.mass$norm.mass = (mean.fit.mass$Mean_mass - mean.fit.mass$Mean_mass_bird)+mean(mean.fit.mass$Mean_mass_bird)

fig = ggplot(data=mean.fit.mass, aes(x=treatment.wk, y=norm.mass)) +
  geom_boxplot(aes(fill=treatment.wk)) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato", "cyan")) +
  guides(fill=FALSE) +
  ylab("Dusk mass (g)") +
  xlab("") +
  ylim(76,90) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2.5, y=88, yend=88, size=.5) +
  annotate("text", x=1.75, y=88.25, label = "NS", size=4) +
  annotate("segment", x=2.5, xend=4, y=88.5, yend=88.5, size=.5) +
  annotate("text", x=3.25, y=88.75, label = "*", size=4) +
  annotate("segment", x=1, xend=4, y=89, yend=89, size=.5) +
  annotate("text", x=2.5, y=89.25, label = "NS", size=4)
fig
win.metafile("Exp 1 dusk mass.wmf")
fig
dev.off()


fit.results$treatment = relevel(fit.results$treatment, ref = "FS1")
m = lmer(mass.18 ~ treatment + (1|room/bird), data=fit.results)
summary(m)
confint(m)
anova(m) # No change under FI

fit.results$treatment = relevel(fit.results$treatment, ref = "FS2")
m1 = lmer(mass.18 ~ treatment + (1|room/bird), data=fit.results)
summary(m1)
confint(m1)

# now refit the above model on standardised data
fit.results$treatment = relevel(fit.results$treatment, ref = "FS1")
m2 = lmer(scale(mass.18) ~ treatment + (1|room/bird), data=fit.results)
summary(m2)

# output the meta-data
output.dusk = data.frame("exp" = "Exp 1","aviary" = "all", "variable" = "mass.dusk",
                         "mean.FS" = mass.treat$mean.mass[1],
                         "mean.FI" = mass.treat$mean.mass[2],
                         "beta" = coef(summary(m))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m))["treatmentFI", "Std. Error"],
                         "standard.beta" = coef(summary(m2))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatmentFI", "Std. Error"])



# Now calculate the effects of FI on dusk mass by aviary
fit.results$treatment = relevel(fit.results$treatment, ref = "FS1")
# room 114
fit.results.114 = fit.results[fit.results$room=="114", ]
m.114 = lmer(mass.18 ~ treatment + (1|bird), data=fit.results.114)
summary(m.114)
m2.114 = lmer(scale(mass.18) ~ treatment + (1|bird), data=fit.results.114)
summary(m2.114)
output.dusk.114 = data.frame("exp" = "Exp 1","aviary" = "114", "variable" = "mass.dusk",
                             "mean.FS" = mean.fit.mass.room$mean.mass[1],
                             "mean.FI" = mean.fit.mass.room$mean.mass[4],
                             "beta" = coef(summary(m.114))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m.114))["treatmentFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2.114))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2.114))["treatmentFI", "Std. Error"])

# room 115
fit.results.115 = fit.results[fit.results$room=="115", ]
m.115 = lmer(mass.18 ~ treatment + (1|bird), data=fit.results.115)
summary(m.115)
m2.115 = lmer(scale(mass.18) ~ treatment + (1|bird), data=fit.results.115)
summary(m2.115)
output.dusk.115 = data.frame("exp" = "Exp 1","aviary" = "115", "variable" = "mass.dusk",
                             "mean.FS" = mean.fit.mass.room$mean.mass[2],
                             "mean.FI" = mean.fit.mass.room$mean.mass[5],
                             "beta" = coef(summary(m.115))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m.115))["treatmentFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2.115))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2.115))["treatmentFI", "Std. Error"])

# room 116
fit.results.116 = fit.results[fit.results$room=="116", ]
m.116 = lmer(mass.18 ~ treatment + (1|bird), data=fit.results.116)
summary(m.116)
m2.116 = lmer(scale(mass.18) ~ treatment + (1|bird), data=fit.results.116)
summary(m2.116)
output.dusk.116 = data.frame("exp" = "Exp 1","aviary" = "116", "variable" = "mass.dusk",
                             "mean.FS" = mean.fit.mass.room$mean.mass[3],
                             "mean.FI" = mean.fit.mass.room$mean.mass[6],
                             "beta" = coef(summary(m.116))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m.116))["treatmentFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2.116))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2.116))["treatmentFI", "Std. Error"])





#### Exploring the relationship between body weight and consumption ####


# Because we only have room-level measures of food eaten it makes sense to calculate the room-level mass of bird too.
# calculate mean bird mass per day and merge into consumption dataset


# sort f1 by room and day
f1 = f1[order(f1[,1], f1[,4]), ]

f1$treatment = relevel(f1$treatment, ref = "FS1")
mean.bird.mass = summarise(group_by(fit.results, room, day.exp), bird.dawn.mass = mean(mass.9, na.rm = TRUE), bird.dusk.mass = mean(mass.18, na.rm = TRUE))
mean.bird.mass$row.no = seq(1:length(mean.bird.mass$room))

f1$row.no = seq(1:length(f1$day.exp))

f1 = merge(f1, mean.bird.mass, by = "row.no")
f1$eaten.bird = f1$total.eaten/2


# Do treatment and consumption the previous day predict dawn mass?
eaten.yesterday = f1$eaten.bird
eaten.yesterday = eaten.yesterday[1:length(eaten.yesterday)-1]
eaten.yesterday = as.numeric(c(NA, eaten.yesterday))
f1$eaten.yesterday = eaten.yesterday
f1$eaten.yesterday[f1$day.exp.x==1] = NA

treatment.yesterday = f1$treatment
treatment.yesterday = as.character(treatment.yesterday[1:length(treatment.yesterday)-1])
treatment.yesterday = c(NA, treatment.yesterday)

f1$treatment.yesterday = as.factor(treatment.yesterday)
f1$treatment.yesterday[f1$day.exp.x==1] = NA


f1$treatment.yesterday = relevel(f1$treatment.yesterday, ref = "FS1")
m = lmer(bird.dawn.mass ~ treatment.yesterday + eaten.yesterday + (1|room.x), data=f1)
summary(m) # dawn mass is predicted by consumption.
confint(m)
anova(m)

fig = ggplot(data=f1, aes(x=eaten.yesterday, y=bird.dawn.mass)) +
  geom_point(aes(colour=treatment.yesterday)) +
  geom_smooth(method = "lm", colour = "black") +
  scale_colour_manual(values=c("cyan", "tomato", "cyan")) +
  guides(fill=FALSE) +
  ylab("Dawn mass (g)") +
  xlab("Food consumed previous day (g)") +
  #annotate("text", x=2.5, y=85.6, label = "Experiment 3", size=5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig


# Do treatment and consumption on the current day predict dusk mass?

f1$treatment = relevel(f1$treatment, ref = "FS1")
m = lmer(bird.dusk.mass ~ treatment + eaten.bird + (1|room.x), data=f1)
summary(m) # dusk mass is predicted by treatment that day but not by consumption.
confint(m)
anova(m)

f1$treatment = factor(f1$treatment, levels = c("FS1", "FI", "FS2"))
fig = ggplot(data=f1, aes(x=eaten.bird, y=bird.dusk.mass)) +
  geom_point(aes(colour=treatment)) +
  geom_smooth(method = "lm", colour = "black") +
  scale_colour_manual(values=c("cyan", "tomato","cyan")) +
  guides(fill=FALSE) +
  ylab("Dusk mass (g)") +
  xlab("Food consumed that day (g)") +
  #annotate("text", x=2.5, y=85.6, label = "Experiment 3", size=5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig




#### Models of efficiency ####


# compute dawn efficiency and ask whether this differs by treatment
f1$efficiency.dawn = f1$bird.dawn.mass/f1$eaten.yesterday

mean.treat.room = summarise(group_by(f1, treatment, room.x), mean.efficiency = mean((efficiency.dawn), na.rm=T))
mean.treat = summarise(group_by(mean.treat.room, treatment), mean.efficiency = mean((mean.efficiency), na.rm=T))

# within-based pair centering based on raw values for plotting
f1$room = f1$room.x
mean.room = summarise(group_by(f1, room), mean.efficiency.room.dawn = mean((efficiency.dawn), na.rm=T))
f1 = merge(f1,mean.room, by="room")
# within-pair centering followed by adding back the grand mean so that treatment effects are relocated relative to the grand mean
f1$norm.eff = ((f1$efficiency.dawn) - f1$mean.efficiency.room.dawn)+(mean((f1$efficiency.dawn), na.rm=T))

fig = ggplot(data=f1, aes(x=treatment.wk, y=norm.eff)) +
  geom_boxplot(aes(fill=treatment.wk)) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato", "cyan")) +
  ylab("Efficiency") +
  xlab("") +
  guides (fill = FALSE) +
  ylim(3,9) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2.5, y=8, yend=8, size=.5) +
  annotate("text", x=1.75, y=8.2, label = "***", size=4) +
  annotate("segment", x=2.5, xend=4, y=8.4, yend=8.4, size=.5) +
  annotate("text", x=3.25, y=8.6, label = "NS", size=4) +
  annotate("segment", x=1, xend=4, y=8.8, yend=8.8, size=.5) +
  annotate("text", x=2.5, y=9, label = "***", size=4)
fig
win.metafile("Exp 1 efficiency.wmf")
fig
dev.off()

# Does treatment predict dawn efficiency?
f1$treatment.yesterday = relevel(f1$treatment.yesterday, ref = "FS1")
m = lmer(efficiency.dawn ~ treatment.yesterday + (1|room.x), data=f1, na.action = na.omit)
summary(m)
confint(m)
anova(m)

f1$treatment.yesterday = relevel(f1$treatment.yesterday, ref = "FS2")
m1 = lmer(efficiency.dawn ~ treatment.yesterday + (1|room.x), data=f1, na.action = na.omit)
summary(m1)
confint(m1)

f1$treatment.yesterday = relevel(f1$treatment.yesterday, ref = "FS1")
m2 = lmer(scale(efficiency.dawn) ~ treatment.yesterday + (1|room.x), data=f1, na.action = na.omit)
summary(m2)

# output the meta-data
output.dawn.eff = data.frame("exp" = "Exp 1","aviary" = "all", "variable" = "efficiency.dawn",
                             "mean.FS" = mean.treat$mean.efficiency[1],
                             "mean.FI" = mean.treat$mean.efficiency[2],
                             "beta" = coef(summary(m))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m))["treatment.yesterdayFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m))["treatment.yesterdayFI", "Std. Error"])



# Now calculate the effects of FI on dawn efficiency by aviary
# room 114
f1.114 = f1[f1$room=="114", ]
m.114 = lm(efficiency.dawn ~ treatment.yesterday, data=f1.114)
summary(m.114)
m2.114 = lm(scale(efficiency.dawn) ~ treatment.yesterday, data=f1.114)
summary(m2.114)
output.dawn.eff.114 = data.frame("exp" = "Exp 1","aviary" = "114", "variable" = "efficiency.dawn",
                             "mean.FS" = mean.treat.room$mean.efficiency[1],
                             "mean.FI" = mean.treat.room$mean.efficiency[4],
                             "beta" = coef(summary(m.114))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m.114))["treatment.yesterdayFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2.114))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2.114))["treatment.yesterdayFI", "Std. Error"])

# room 115
f1.115 = f1[f1$room=="115", ]
m.115 = lm(efficiency.dawn ~ treatment.yesterday, data=f1.115)
summary(m.115)
m2.115 = lm(scale(efficiency.dawn) ~ treatment.yesterday, data=f1.115)
summary(m2.115)
output.dawn.eff.115 = data.frame("exp" = "Exp 1","aviary" = "115", "variable" = "efficiency.dawn",
                                 "mean.FS" = mean.treat.room$mean.efficiency[2],
                                 "mean.FI" = mean.treat.room$mean.efficiency[5],
                                 "beta" = coef(summary(m.115))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m.115))["treatment.yesterdayFI", "Std. Error"],
                                 "standard.beta" = coef(summary(m2.115))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2.115))["treatment.yesterdayFI", "Std. Error"])

# room 116
f1.116 = f1[f1$room=="116", ]
m.116 = lm(efficiency.dawn ~ treatment.yesterday, data=f1.116)
summary(m.116)
m2.116 = lm(scale(efficiency.dawn) ~ treatment.yesterday, data=f1.116)
summary(m2.116)
output.dawn.eff.116 = data.frame("exp" = "Exp 1","aviary" = "116", "variable" = "efficiency.dawn",
                                 "mean.FS" = mean.treat.room$mean.efficiency[3],
                                 "mean.FI" = mean.treat.room$mean.efficiency[6],
                                 "beta" = coef(summary(m.116))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m.116))["treatment.yesterdayFI", "Std. Error"],
                                 "standard.beta" = coef(summary(m2.116))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2.116))["treatment.yesterdayFI", "Std. Error"])




#### Final output dataframe for meta-analysis ####

# output for experiment as a whole
output = rbind(output.food, output.dawn, output.dusk, output.dawn.eff)

baseline.mean = mean(baseline.mass$baseline.mass)

output$baseline.mass = baseline.mean

write.csv(output,"Exp 1 data for meta-analysis v3.csv")


# output split by aviary
output.aviary = rbind(output.eaten.114, output.eaten.115, output.eaten.116, 
                      output.dawn.114,output.dawn.115,output.dawn.116,
                      output.dusk.114,output.dusk.115,output.dusk.116,
                      output.dawn.eff.114, output.dawn.eff.115, output.dawn.eff.116)

output.aviary = merge(output.aviary,baseline.mass, by = "aviary")

write.csv(output.aviary,"Exp 1 data for meta-analysis by aviary v3.csv")
