#### Exp 2: Analysis of food eaten and masses ####


# This experiment had 6 birds sharing two SFS units in a single room
# Two treatments: 7 days FS followed by 7 days FI

# Written by Melissa Bateson


#remove any existing data/values in the global environment
rm(list=ls())


# load necessary packages
library(dplyr)
library(ggplot2)
library(reshape2)
library(lubridate)
library(psych)
library(lme4)
library(lmerTest)
library(tidyr)


#### Define some useful functions ####

# function to turn hr:min:sec to minutes since midnight as a decimal
decimateTime=function(time) {
  time=as.numeric(unlist(strsplit(time, ":")))
  time = time[1]*60+time[2]+time[3]/60
  return(time)
}

#create a new version of length which can handle NA's: if na.rm==T, don't count them
length2 <- function (x, na.rm=FALSE) {
  if (na.rm) sum(!is.na(x))
  else       length(x)
}



#### Anaysis of daily food consumption ####

food = read.csv("Exp 2 food consumption data.csv")

food$date = as.POSIXct(food$date)


f1 = food[is.na(food$total.eaten)==FALSE,]


# code the phases of the experiment
# Stabilisation: 
# Food.security: 02/05/2019 - 08/05/2019
# Food.insecurity: 09/05/2019 - 15/05/2019

f1$treatment[f1$date>"2019-05-01"&f1$date<"2019-05-09"]="FS"
f1$treatment[f1$date>"2019-05-08"&f1$date<"2019-05-16"]="FI"

f1$treatment = factor(f1$treatment, levels = c("FS","FI"))

# create a  column with day.exp
f1$day.exp = seq(1,length(f1$date))

# create a 'day.treat' variable to indicate the day of each treatment and merge it into the main dataframe
d.date= unique(subset(f1,select=c("date","treatment")))
d.date = d.date%>%
  group_by(treatment)%>%
  mutate(day.treat=seq_along(date))
d.date= subset(d.date,select=c("date","day.treat"))
f1 = merge(f1,d.date, by = "date")


# Basic stats per bird

mean.eaten = summarise(group_by(f1, treatment), mean.food.eaten = mean(total.eaten/6), 
                       sd.food.eaten = sd(total.eaten/6), n.food.eaten = length(total.eaten))

# calculate the percentage drop in consumption between FI and FS1
percent.drop.FI = 100*(mean.eaten$mean.food.eaten[1]-mean.eaten$mean.food.eaten[2])/mean.eaten$mean.food.eaten[1]


# Plot a graph of consumption by treatment (using all days)
fig = ggplot(data=f1, aes(x=treatment, y=total.eaten/6)) +
  geom_boxplot(aes(fill=treatment)) +
  scale_fill_manual(values=c("cyan", "tomato")) +
  #ylab("Food consumption (g/day)") +
  ylab("") +
  xlab("") +
  guides (fill = FALSE) +
  ylim(9,22) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=20, yend=20, size=.5) +
  annotate("text", x=1.5, y=20.2, label = "NS", size=4)
fig
win.metafile("Exp 2 consumption.wmf")
fig
dev.off()

# Model amount eaten
m = lm((total.eaten/6) ~ treatment, data = f1)
summary(m) # No effect of FI on amount eaten
confint(m)
anova(m)
m2 = lm(scale(total.eaten/6) ~ treatment, data = f1)
summary(m2)

# output the meta-data
output.food = data.frame("exp" = "Exp 2","aviary" = "single", "variable" = "food.eaten",
                         "mean.FS" = mean.eaten$mean.food.eaten[1],
                         "mean.FI" = mean.eaten$mean.food.eaten[2],
                         "beta" = coef(summary(m))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m))["treatmentFI", "Std. Error"],
                         "standard.beta" = coef(summary(m2))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatmentFI", "Std. Error"])



#### Mass data ####

#read in the mass data 
mass = read.csv("Exp 2 mass data.csv",sep=" ",header=F)
colnames(mass) = c("date","time","balance","RFID","mass_kg")
#check for blank rows
sapply(mass, function(x) sum(is.na(x))) # none
# d.na = mass[is.na(mass$RFID)==TRUE,] # if present, examine these rows and clean the dataset

xtabs(~mass$RFID) # check RFIDs present in the file to make sure these are all in the rfid file

# read in the RFID file
tag=read.delim("rfids.txt", header=T)

# merge the two files to incorporate bird IDs into mass dataframe
d=merge(tag, mass, by="RFID", all.y=F)
head(d)


d$Room = NULL


xtabs(~d$Bird)

# sort out the data types
d$RFID = factor(d$RFID)
#convert mass in kg to mass in g
d$mass_g = d$mass_kg*1000

#now want to get the times/dates in a usable format
#create a datetime variable (useful if you need to plot both date and time on the x axis)
d$date_time = ymd_hms(paste(d$date, d$time))

#create a time only variable
d$time.only = strptime(d$time, format = "%H:%M:%S")

#bin mass events by 1h
d$bin.1h = as.numeric(format(d$date_time,"%H"))

# convert times and dates to correct data type
d$time.only = as.POSIXct(d$time.only)
d$date = as.POSIXct(d$date)

# create a decimal time variable (minutes since midnight)
d$time.dec = as.character(d$time)
d$time.dec = (as.numeric(as.POSIXct(paste("2014-01-01", d$time.dec))) - 
                as.numeric(as.POSIXct("2014-01-01 0:0:0")))/60 # this code converts h:m:s to decimal minutes from midnight

# sort the dataset by date and time
d=d[order(d$date_time), ]


# code the phases of the experiment
# Food.security: 02/05/2019 - 08/05/2019
# Food.insecurity: 09/05/2019 - 15/05/2019

d$treatment[d$date>"2019-05-01"&d$date<"2019-05-09"]="FS"
d$treatment[d$date>"2019-05-08"&d$date<"2019-05-16"]="FI"

d$treatment = factor(d$treatment, levels = c("FS","FI"))



# create a subset of the data that only contains the experimental phases
d1 = d[d$date>"2019-05-01",]
# remove data from test mass
d1 = d1[d1$Bird!="test",]
xtabs(~d1$Bird)
d1$Bird = droplevels(d1$Bird)
levels(d1$Bird)

# exclude masses collected before 0900 and after 1800
d1 = d1[(d1$time.dec>=540),]
d1 = d1[(d1$time.dec<1080),]
max(d1$time.only)
min(d1$time.only)

#Create a 'day' variable to indicate the day of each phase and merge it into the main dataframe
d.date= unique(subset(d1,select=c("date","treatment")))
d.date = d.date%>%
  group_by(treatment)%>%
  mutate(day.treat=seq_along(date))
d.date= subset(d.date,select=c("date","day.treat"))
d1 = merge(d1,d.date, by = "date")


# create a unique column with a unique row number (to be used later when remerging dataframes)
d1$row.number = seq(1,length(d1$date))

no.masses = summarise(group_by(d1,Bird), n = length2(mass_g, na.rm = TRUE))
mean(no.masses$n)/14 # mean number of masses/bird/day = 31.99
mean(no.masses$n)/(14*9) # mean number of masses/bird/hr = 3.55


#### Polynomial fitting ####

# The aim of this part of the script is to fit the mass data obtained for each individual bird on each day of the experiment.
# The reason for this is to obtain a model of the mass change over the day that eliminates the noise in the measurements.
# We can then use the fitted values from the model in subsequent analyses (e.g. the maximum fitted mass in a day; the fitted mass at 1800 hrs)

# set the mass band either side of the fitted function for retaining masses
# I have finally settled on quite a high value that only excludes very extreme masses.
g.filter = 3

# make a new data frame to accumulate cleaned and fitted masses in
d.clean = data.frame(time.dec = numeric(0),time_s.clean = numeric(0), mass_g.clean= numeric(0), m.fit = numeric(0))
#make empty vectors for results
bird = NULL
treatment = NULL
day.treat = NULL
no.masses = NULL
no.masses.clean = NULL 
linear.p = NULL
quadratic.p = NULL
cubic.p = NULL
r_sq.fit = NULL
AIC.fit = NULL
mass.earliest = NULL
mass.latest = NULL
mass.max = NULL
mass.min = NULL
mass.9 = NULL
mass.10 = NULL
mass.11 = NULL
mass.12 = NULL
mass.13 = NULL
mass.14 = NULL
mass.15 = NULL
mass.16 = NULL
mass.17 = NULL
mass.18 = NULL
time.max.mass = NULL
time.min.mass = NULL
time.earliest.mass = NULL
time.latest.mass = NULL

row = 1

for(i in c("GGGG",  "P17GG", "P13GG", "P27GG", "P22GG", "P25GG")){ print(i)
  for(j in c("FS","FI")){ print(j)
    for(k in 1:7){ print(k)

bird[row] = i
treatment[row] = j
day.treat[row] = k

s = subset(d1, (Bird == i & treatment == j & day.treat == k))

# stuff that goes inside the function

no.masses[row] = length(s$mass_g) # save the number of masses that day

# check to see that there is enough data to do the fitting
# 'degree' must be less than number of unique points; need degree+1 points for fit that is not just the data
# don't fit the data if there are no masses before 1100

if ((length(s$mass_g)<10)|(min(s$time.dec)>660)) {
  # Set fit parameters to NA
  linear.p[row] = NA
  quadratic.p[row] = NA
  cubic.p[row] = NA
  r_sq.fit[row] = NA
  AIC.fit[row] = NA
  mass.earliest[row] = NA
  mass.latest[row] = NA
  mass.max[row] = NA
  mass.min[row] = NA
  mass.9[row] = NA
  mass.10[row] = NA
  mass.11[row] = NA
  mass.12[row] = NA
  mass.13[row] = NA
  mass.14[row] = NA
  mass.15[row] = NA
  mass.16[row] = NA
  mass.17[row] = NA
  mass.18[row] = NA
  time.max.mass[row] = NA
  time.min.mass[row] = NA
  time.earliest.mass[row] = NA
  time.latest.mass[row] = NA
  
  row = row + 1
  }

  if ((length(s$mass_g) >=10)&(min(s$time.dec)<=660)) {

  m = lm(mass_g ~ poly(time.dec,degree=3), data = s) # NB this fits a cubic orthogonal polynomial

  s$m.fit.raw = predict(m)

  # calculate a fixed mass band for inclusion either side of the fitted slope
  s$m.lb=(s$m.fit.raw - g.filter)
  s$m.ub=(s$m.fit.raw + g.filter)
  # filter out any data outside these bounds
  s1 = subset(s, (mass_g<(m.fit.raw+g.filter) & mass_g>(m.fit.raw-g.filter)))
  s1$mass_g.clean = s1$mass_g
  s1$time_s.clean = s1$time.dec
  
  no.masses.clean[row] = length(s1$mass_g.clean) # save the number of masses retained in the final cleaned dataset
  
  # check to see that there is enough data to do the fitting
  # 'degree' must be less than number of unique points; need degree+1 points for fit that is not just the data
  # don't fit the data if there are no masses before 1100
  
  if ((length(s1$mass_g.clean)<10)|(min(s1$time.dec)>660)) {
    # Set fit parameters to NA
    linear.p[row] = NA
    quadratic.p[row] = NA
    cubic.p[row] = NA
    r_sq.fit[row] = NA
    AIC.fit[row] = NA
    mass.earliest[row] = NA
    mass.latest[row] = NA
    mass.max[row] = NA
    mass.min[row] = NA
    mass.9[row] = NA
    mass.10[row] = NA
    mass.11[row] = NA
    mass.12[row] = NA
    mass.13[row] = NA
    mass.14[row] = NA
    mass.15[row] = NA
    mass.16[row] = NA
    mass.17[row] = NA
    mass.18[row] = NA
    time.max.mass[row] = NA
    time.min.mass[row] = NA
    time.earliest.mass[row] = NA
    time.latest.mass[row] = NA
    
    row = row + 1
  }
  
  if ((length(s1$mass_g.clean) >=10)&(min(s1$time.dec)<=660)) {
    

  # refit the cleaned dataset
  m1 = lm(mass_g.clean ~ poly(time_s.clean,degree=3), data = s1, na.action = na.exclude) 
  s1$m.fit = predict(m1) # save the fitted values from the curve fitting

  # extract p-values from the fit
  linear.p[row] = summary(m1)$coefficients[2,4] # p-value for the linear term in the orthogonal fit
  quadratic.p[row] = summary(m1)$coefficients[3,4] # p-value for the quadratic term in the orthogonal fit
  cubic.p[row] = summary(m1)$coefficients[4,4] # p-value for the cubic term in the orthogonal fit

  # NB need to fit non-orthogonal polynomial to get the correct coefficients for the fitted line
  m2 = lm(mass_g.clean ~ time_s.clean + I(time_s.clean^2) + I(time_s.clean^3), data = s1, na.action = na.exclude)
  # eqn for cubic: y = a + bx + cx^2 + dx^3 where x is the minutes since midnight
  # extract parameter estimates b, c and d
  par.a = as.numeric(m2$coefficients[1])
  par.b = as.numeric(m2$coefficients[2])
  par.c = as.numeric(m2$coefficients[3])
  par.d = as.numeric(m2$coefficients[4])

  # calculate the fitted mass at each hour by plugging the relevant times into the fitted funtion
  mass.9[row] = par.a + (par.b*540) + (par.c*(540^2)) + (par.d*(540^3))
  mass.10[row] = par.a + (par.b*600) + (par.c*(600^2)) + (par.d*(600^3))
  mass.11[row] = par.a + (par.b*660) + (par.c*(660^2)) + (par.d*(660^3))
  mass.12[row] = par.a + (par.b*720) + (par.c*(720^2)) + (par.d*(720^3))
  mass.13[row] = par.a + (par.b*780) + (par.c*(780^2)) + (par.d*(780^3))
  mass.14[row] = par.a + (par.b*840) + (par.c*(840^2)) + (par.d*(840^3))
  mass.15[row] = par.a + (par.b*900) + (par.c*(900^2)) + (par.d*(900^3))
  mass.16[row] = par.a + (par.b*960) + (par.c*(960^2)) + (par.d*(960^3))
  mass.17[row] = par.a + (par.b*1020) + (par.c*(1020^2)) + (par.d*(1020^3))
  mass.18[row] = par.a + (par.b*1080) + (par.c*(1080^2)) + (par.d*(1080^3))

  # Extract parameters from the fit
  r_sq.fit[row] = summary(m1)$r.squared # r-squared for the fit
  AIC.fit[row] = AIC(m1) # AIC for the fit
  mass.earliest[row] = s1$m.fit[which(s1$time_s.clean==min(s1$time_s.clean))] # the earliest fitted mass
  mass.latest[row] = s1$m.fit[which(s1$time_s.clean==max(s1$time_s.clean))] # the latest fitted mass
  mass.max[row] = max(s1$m.fit) # the maximumn fitted mass
  mass.min[row] = min(s1$m.fit) # the minimum fitted mass
  time.max.mass[row] = median(s1$time_s.clean[which(s1$m.fit==max(s1$m.fit))]) # finds the time with the max value (median if more than one)
  time.min.mass[row] = median(s1$time_s.clean[which(s1$m.fit==min(s1$m.fit))]) # finds the time with the min value (median if more than one)
  time.earliest.mass[row] = min(s1$time_s.clean) # the time at which the first fitted mass occurred
  time.latest.mass[row] = max(s1$time_s.clean) # the time at which the last fitted mass occurred
  
  # we need a rule to exclude any fits when the latest mass that day is substantially before the time of the fit. 
  # Exclude any fits for which the latest mass that day is more than one hour previously.
  if (time.latest.mass[row] < 600) {mass.11[row]=NA}
  if (time.latest.mass[row] < 660) {mass.12[row]=NA}
  if (time.latest.mass[row] < 720) {mass.13[row]=NA}
  if (time.latest.mass[row] < 780) {mass.14[row]=NA}
  if (time.latest.mass[row] < 840) {mass.15[row]=NA}
  if (time.latest.mass[row] < 900) {mass.16[row]=NA}
  if (time.latest.mass[row] < 960) {mass.17[row]=NA}
  if (time.latest.mass[row] < 1020) {mass.18[row]=NA}

  row = row + 1
  

  s1 = subset(s1, select = c("row.number","time_s.clean","mass_g.clean","m.fit"))
  d.clean = rbind.data.frame(d.clean, s1)
  }

}

    }
  }
}

d.new = merge(d1,d.clean, by = "row.number", all.x = FALSE, all.y = TRUE)

fit.results = data.frame(bird, treatment, day.treat, no.masses,no.masses.clean, linear.p, quadratic.p, cubic.p, r_sq.fit, AIC.fit, mass.earliest, 
                         mass.latest, mass.max, mass.min,
                         mass.9, mass.10, mass.11, mass.12, mass.13, mass.14, mass.15, mass.16, mass.17, mass.18,
                         time.max.mass, time.min.mass, time.earliest.mass, time.latest.mass)

# create a column with the day of the experiment
fit.results$day.exp = rep(seq(1,14),6)

write.csv(fit.results, "Exp2_fit_results.csv")


# clean up the dataframe d.new
d.new$bird = d.new$Bird
d.new$Bird = NULL
d.new$treatment = d.new$phase
d.new$phase = NULL
d.new$day.treat = d.new$day
d.new$day = NULL
d.new$mass_g.fit = d.new$m.fit
d.new$m.fit = NULL

write.csv(d.new, "Exp2_mass_data_fitted_and_cleaned.csv")

describe(fit.results)



#### Fit some models to the fitted mass data ####

fit.results$treatment = factor(fit.results$treatment, levels = c("FS","FI"))
fit.results$treatment = relevel(fit.results$treatment, ref = "FS")


# calculate mean baseline mass for each aviary
baseline = fit.results[fit.results$treatment=="FS",]
baseline.mass = summarise(group_by(baseline), baseline.mass = mean(mass.9, na.rm = TRUE))

# dawn mass (mean of fitted mass at 0900)
# first create a variable for treatment yesterday
treatment.yesterday = fit.results$treatment
treatment.yesterday = as.character(treatment.yesterday[1:length(treatment.yesterday)-1])
treatment.yesterday = c(NA, treatment.yesterday)
fit.results$treatment.yesterday = as.factor(treatment.yesterday)
fit.results$treatment.yesterday[fit.results$day.exp==1] = NA
fit.results$treatment.yesterday = relevel(fit.results$treatment.yesterday, ref = "FS")

# now plot the data splitting FS2 into two bars
# first get the means for each bird in each treatment
fit.results2 = fit.results[is.na(fit.results$treatment.yesterday)==FALSE,]
mean.fit.mass = summarise(group_by(fit.results2,bird,treatment.yesterday), Mean_mass = mean(mass.9, na.rm = TRUE))
#calculate mean mass for each treatment
mass.treat = summarise(group_by(mean.fit.mass, treatment.yesterday), mean.mass = mean(Mean_mass), sd.mass = sd(Mean_mass), n.mass = length2(Mean_mass))

# now calculate overall mean for each bird and merge this back into the dataframe
mean.mean.mass = summarise(group_by(mean.fit.mass, bird), Mean_mass_bird = mean(Mean_mass))
mean.fit.mass = merge(mean.fit.mass,mean.mean.mass, by="bird")
# within-subject centering followed by adding back the grant mean so that phase effects are relocated relative to the grand mean
mean.fit.mass$norm.mass = (mean.fit.mass$Mean_mass - mean.fit.mass$Mean_mass_bird)+mean(mean.fit.mass$Mean_mass_bird)

fig = ggplot(data=mean.fit.mass, aes(x=treatment.yesterday, y=norm.mass)) +
  geom_boxplot(aes(fill=treatment.yesterday)) +
  scale_fill_manual(values=c("cyan", "tomato")) +
  guides(fill=FALSE) +
  ylim(72.5,82.5) +
  #ylab("Dawn mass (g)") +
  ylab("") +
  xlab("") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=81.5, yend=81.5, size=.5) +
  annotate("text", x=1.5, y=81.75, label = "***", size=4)
fig
win.metafile("Exp 2 dawn mass.wmf")
fig
dev.off()

m = lmer(mass.9 ~ treatment.yesterday + (1|bird), data=fit.results, na.action = na.omit)
summary(m) # Dawn mass is significantly higher under FI.
confint(m)
anova(m)
m2 = lmer(scale(mass.9) ~ treatment.yesterday + (1|bird), data=fit.results, na.action = na.omit)
summary(m2)

# output the meta-data
output.dawn = data.frame("exp" = "Exp 2","aviary" = "single", "variable" = "mass.dawn",
                         "mean.FS" = mass.treat$mean.mass[1],
                         "mean.FI" = mass.treat$mean.mass[2],
                         "beta" = coef(summary(m))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m))["treatment.yesterdayFI", "Std. Error"],
                         "standard.beta" = coef(summary(m2))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatment.yesterdayFI", "Std. Error"])



# dusk mass (mean of fitted mass at 1800)

# first get the means for each bird in each treatment
mean.fit.mass = summarise(group_by(fit.results,bird,treatment), Mean_mass = mean(mass.18, na.rm = TRUE))

#calculate mean mass for each treatment
mass.treat = summarise(group_by(mean.fit.mass, treatment), mean.mass = mean(Mean_mass), sd.mass = sd(Mean_mass), n.mass = length2(Mean_mass))

# now calculate overall mean for each bird and merge this back into the dataframe
mean.mean.mass = summarise(group_by(mean.fit.mass, bird), Mean_mass_bird = mean(Mean_mass))
mean.fit.mass = merge(mean.fit.mass,mean.mean.mass, by="bird")
# within-subject centering followed by adding back the grant mean so that phase effects are relocated relative to the grand mean
mean.fit.mass$norm.mass = (mean.fit.mass$Mean_mass - mean.fit.mass$Mean_mass_bird)+mean(mean.fit.mass$Mean_mass_bird)

fig = ggplot(data=mean.fit.mass, aes(x=treatment, y=norm.mass)) +
  geom_boxplot(aes(fill=treatment)) +
  scale_fill_manual(values=c("cyan", "tomato")) +
  guides(fill=FALSE) +
  ylim(76,90) +
  #ylab("Dusk mass (g)") +
  ylab("") +
  xlab("") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=89, yend=89, size=.5) +
  annotate("text", x=1.5, y=89.25, label = "***", size=4)
fig
win.metafile("Exp 2 dusk mass.wmf")
fig
dev.off()


m = lmer(mass.18 ~ treatment + (1|bird), data=fit.results)
summary(m)
confint(m)
anova(m) # Birds got significantly heavier under FI
m2 = lmer(scale(mass.18) ~ treatment + (1|bird), data=fit.results)
summary(m2)

# output the meta-data
output.dusk = data.frame("exp" = "Exp 2","aviary" = "single", "variable" = "mass.dusk",
                         "mean.FS" = mass.treat$mean.mass[1],
                         "mean.FI" = mass.treat$mean.mass[2],
                         "beta" = coef(summary(m))["treatmentFI", "Estimate"], "se.beta" = coef(summary(m))["treatmentFI", "Std. Error"],
                         "standard.beta" = coef(summary(m2))["treatmentFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatmentFI", "Std. Error"])


                        
# Make a graph of the individual weight curves
# dawn mass
# within-subject centering followed by adding back the grant mean so that phase effects are relocated relative to the grand mean
bird.mean.dawn = summarise(group_by(fit.results,bird), bird.mean.dawn = mean(mass.9, na.rm = TRUE))
fit.results = merge(fit.results,bird.mean.dawn, by="bird")
fit.results$norm.mass.9 = (fit.results$mass.9 - fit.results$bird.mean.dawn)+mean(fit.results$mass.9, na.rm = TRUE)
fig = ggplot(data=fit.results, aes(x=as.factor(day.exp), y=norm.mass.9)) +
  geom_boxplot(aes(fill = treatment.yesterday)) +
  geom_vline(xintercept = 8.5) +
  scale_fill_manual(values=c("cyan", "tomato")) +
  guides(fill=FALSE) +
  annotate("text", x = 4.5, y = 91, label = "FS") +
  annotate("text", x = 11.5, y = 91, label = "FI") +
  ylim(73,91) +
  ylab("Dawn mass (g)") +
  xlab("Day in experiment") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig
win.metafile("Exp 2 dawn mass by day.wmf")
fig
dev.off()

# dusk mass
# within-subject centering followed by adding back the grant mean so that phase effects are relocated relative to the grand mean
bird.mean.dusk = summarise(group_by(fit.results,bird), bird.mean.dusk = mean(mass.18, na.rm = TRUE))
fit.results = merge(fit.results,bird.mean.dusk, by="bird")
fit.results$norm.mass.18 = (fit.results$mass.18 - fit.results$bird.mean.dusk)+mean(fit.results$mass.18, na.rm = TRUE)
fig = ggplot(data=fit.results, aes(x=as.factor(day.exp), y=norm.mass.18)) +
  geom_boxplot(aes(fill = treatment)) +
  geom_vline(xintercept = 7.5) +
  scale_fill_manual(values=c("cyan", "tomato")) +
  guides(fill=FALSE) +
  annotate("text", x = 4, y = 91, label = "FS") +
  annotate("text", x = 11, y = 91, label = "FI") +
  ylim(73,91) +
  ylab("Dusk mass (g)") +
  xlab("Day in experiment") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig
win.metafile("Exp 2 dusk mass by day.wmf")
fig
dev.off()




# plot of change in dawn and dusk mass by day of experiment (do I want to show this??)
dawn.mass.day = summarise(group_by(fit.results, treatment,day.exp), mean.dawn.mass = mean(mass.9, na.rm = TRUE))
dusk.mass.day = summarise(group_by(fit.results, treatment,day.exp), mean.dusk.mass = mean(mass.18, na.rm = TRUE))

fig = ggplot() +
  geom_point(data = dawn.mass.day, aes(x = day.exp, y = mean.dawn.mass, colour = treatment), shape = 16) +
  stat_smooth(data = dawn.mass.day, aes(x = day.exp, y = mean.dawn.mass, colour = treatment),method = "lm", se = FALSE, linetype = "dashed") +
  geom_point(data = dusk.mass.day, aes(x = day.exp, y = mean.dusk.mass, colour = treatment), shape = 17) +
  stat_smooth(data = dusk.mass.day, aes(x = day.exp, y = mean.dusk.mass, colour = treatment),method = "lm", se = FALSE) +
  scale_colour_manual(values=c("cyan", "tomato")) +
  ylab("Body mass (g)") +
  xlab("Day of experiment") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig





#### Exploring the relationship between body weight and consumption ####

# Because we only have room-level measures of food eaten it makes sense to calculate the room-level mass of bird too.
# calculate mean bird mass per day and merge into consumption dataset
mean.bird.mass = summarise(group_by(fit.results, day.exp), bird.dawn.mass = mean(mass.9, na.rm = TRUE), bird.dusk.mass = mean(mass.18, na.rm = TRUE))
f1 = merge(f1, mean.bird.mass, by = "day.exp")
f1$eaten.bird = f1$total.eaten/6


# Do treatment and consumption the previous day predict dawn mass?
eaten.yesterday = f1$eaten.bird
eaten.yesterday = eaten.yesterday[1:length(eaten.yesterday)-1]
eaten.yesterday = as.numeric(c(NA, eaten.yesterday))
f1$eaten.yesterday = eaten.yesterday

treatment.yesterday = f1$treatment
treatment.yesterday = as.character(treatment.yesterday[1:length(treatment.yesterday)-1])
treatment.yesterday = c(NA, treatment.yesterday)
f1$treatment.yesterday = as.factor(treatment.yesterday)

m = lm(bird.dawn.mass ~ treatment.yesterday + eaten.yesterday, data=f1)
summary(m) # dawn mass is predicted by treatment the previous day, but not by consumption.
confint(m)
anova(m)
# Note that if you fit the interaction in this model then it is significant
# there is a postive slope in the FI group but not in the FS group - this possibly does suggest that birds ate more under FI?

fig = ggplot(data=f1, aes(x=eaten.yesterday, y=bird.dawn.mass)) +
  geom_point(aes(colour=treatment)) +
  geom_smooth(method = "lm", colour = "black") +
  scale_fill_manual(values=c("cyan", "tomato")) +
  guides(fill=FALSE) +
  ylab("Dawn mass (g)") +
  xlab("Food consumed previous day (g)") +
  #annotate("text", x=2.5, y=85.6, label = "Experiment 3", size=5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig


# Do treatment and consumption on the current day predict dusk mass?
m = lm(bird.dusk.mass ~ treatment*eaten.bird, data=f1)
summary(m) # dusk mass is predicted by treatment that day but not by consumption.
confint(m)
anova(m)

fig = ggplot(data=f1, aes(x=eaten.bird, y=bird.dusk.mass)) +
  geom_point(aes(colour=treatment)) +
  geom_smooth(method = "lm", colour = "black") +
  scale_fill_manual(values=c("cyan", "tomato")) +
  guides(fill=FALSE) +
  ylab("Dusk mass (g)") +
  xlab("Food consumed that day (g)") +
  #annotate("text", x=2.5, y=85.6, label = "Experiment 3", size=5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
fig




#### Models of efficiency ####


# compute dawn efficiency and ask whether this differs by treatment
f1$efficiency.dawn = f1$bird.dawn.mass/f1$eaten.yesterday

mean.eff = summarise(group_by(f1,treatment), mean.eff = mean(efficiency.dawn, na.rm = T))

fig = ggplot(data=f1, aes(x=treatment, y=efficiency.dawn)) +
  geom_boxplot(aes(fill=treatment)) +
  scale_fill_manual(values=c("cyan", "tomato")) +
  #ylab("Efficiency") +
  ylab("") +
  xlab("") +
  guides (fill = FALSE) +
  ylim(3,9) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=8.4, yend=8.4, size=.5) +
  annotate("text", x=1.5, y=8.6, label = "NS", size=4) 
fig
win.metafile("Exp 2 efficiency.wmf")
fig
dev.off()

# Does treatment predict dawn efficiency?
f1$treatment.yesterday = relevel(f1$treatment.yesterday, ref = "FS")
m = lm(efficiency.dawn ~ treatment.yesterday, data=f1)
summary(m)
confint(m)
m2 = lm(scale(efficiency.dawn) ~ treatment.yesterday, data=f1)
summary(m2)

# output the meta-data
output.dawn.eff = data.frame("exp" = "Exp 2","aviary" = "single", "variable" = "efficiency.dawn",
                             "mean.FS" = mean.eff$mean.eff[1],
                             "mean.FI" = mean.eff$mean.eff[2],
                             "beta" = coef(summary(m))["treatment.yesterdayFI", "Estimate"], "se.beta" = coef(summary(m))["treatment.yesterdayFI", "Std. Error"],
                             "standard.beta" = coef(summary(m2))["treatment.yesterdayFI", "Estimate"], "standard.se.beta" = coef(summary(m2))["treatment.yesterdayFI", "Std. Error"])



#### Final output dataframe for meta-analysis ####

output = rbind(output.food, output.dawn, output.dusk, output.dawn.eff)

output = cbind(output, baseline.mass)

write.csv(output,"Exp 2 data for meta-analysis v3.csv")