#### Exp 4: Analysis of foraging data ####

# Written by Melissa Bateson



#remove any existing data/values in the global environment
rm(list=ls())



library(dplyr)
library(ggplot2)
library(reshape2)
library(lubridate)
library(psych)
library(lme4)
library(lmerTest)
library(tidyr)


#Read in .csv file
d = read.csv("Exp 4 peck data.csv")
crumb = read.csv("Exp 4 food consumption data.csv")

cr = data.frame(crumb$date, crumb$total_eaten)
colnames(cr)[colnames(cr) =="crumb.date"] = "date"
colnames(cr)[colnames(cr) =="crumb.total_eaten"] = "total_eaten"
d = merge(d, cr, by = "date") # merge in crumb data

#Specify variable type
d$balance<-factor(d$balance)
d$RFID<-factor(d$RFID)
d$pair<-factor(d$pair)
d$pair.id<-factor(d$pair.id)
d$ring<-factor(d$ring)

#Specify probability factor levels for plotting
d$probability = factor(d$probability, levels = c("1", "0.4", "0.2"))



#Create a datetime variable
d$date_time = ymd_hms(paste(d$date, d$time))

#Specify date variable
d$date = as.Date(d$date,format="%Y-%m-%d")

#Create an hour variable that allows us to select pecks according to the hour they were recorded
d$bin.1h<-as.numeric(format(d$date_time,"%H"))

# Create a decimal time variable (minutes since midnight)
d$time.char = as.character(d$time)
d$time.dec = (as.numeric(as.POSIXct(paste("2014-01-01", d$time.char))) - 
                as.numeric(as.POSIXct("2014-01-01 0:0:0")))/60 # this code converts h:m:s to decimal minutes from midnight

#Create a 'day' variable and merge it into the main dataframe
d.date<-unique(subset(d,select=c("date","pair","probability")))
d.date<-d.date%>%
  group_by(pair,probability)%>%
  mutate(day=seq_along(date))


start = c("2018-03-12","2018-04-25","2018-05-15") #  the dates of catching for each pair
start1 = c("2018-03-26","2018-05-12","2018-06-10") #  start of p(r) = 1 (changeover date)
start0.4 = c("2018-04-07","2018-05-21","2018-06-21") # start of p(r) = 0.4 (changeover date)
start0.2 = c("2018-04-17","2018-05-29","2018-06-30") # start of p(r) = 0.2 (changeover date)
pair = c(1,2,3)
start.date = data.frame(pair,start,start1,start0.4,start0.2)
start.date$start = as.Date(start.date$start)
start.date$start1 = as.Date(start.date$start1)
start.date$start0.4 = as.Date(start.date$start0.4)
start.date$start0.2 = as.Date(start.date$start0.2)

d = merge(d,start.date, by = "pair")

d.date = subset(d.date, select = c("date","day"))
d = merge(d,d.date, by = "date")

d$day.expt = d$date-d$start # the number of days in the expt at the time of a mass
# the number of days in the current treatment at the time of a mass
d$day.treat[d$probability=="1"] = (d$date-d$start1)[d$probability=="1"]
d$day.treat[d$probability=="0.4"] = (d$date-d$start0.4)[d$probability=="0.4"]
d$day.treat[d$probability=="0.2"] = (d$date-d$start0.2)[d$probability=="0.2"]


#Note here, the continuous program ran from 06:15 - 20:45 to give birds 15 mins after dawn to wake up and 15 mins before
#dusk to settle down to sleep.  The starfeeder program ran from when lights were on at 06:00 to when they were off at 21:00.
#That means that while RFIDs and masses can be binned by hour, if we do the same for pecks, those recorded between 06:15-07:00
#and 20:00-20:45 will have 15 minutes less than for all other bins.  Therefore, we must remember to adjust those bins when
#we are creating summaries based on time to make sure we compare like with like. i.e. multiply any quantities by (60/45)



#### Foraging effort: pecks per day ####

d$probability = factor(d$probability, levels = c("1", "0.4", "0.2"))



# Plot total pecks per day
peck.day = summarise(group_by(d,pair.id,probability,day,pair), n=n())
peck.day$pecks.per.hr = peck.day$n/14.5

# plot the data
# first get the means pecks for each bird in each p(r) 
peck.bird = summarise(group_by(peck.day,pair.id,probability), pecks.per.hr = mean(pecks.per.hr, na.rm = TRUE))
peck.prob = summarise(group_by(peck.bird, probability), mean.pecks = mean(pecks.per.hr), sd.pecks = sd(pecks.per.hr))
peck.prob$se = peck.prob$sd.pecks/sqrt(6)

# now calculate overall mean for each bird and merge this back into the above dataframe
mean.peck.bird = summarise(group_by(peck.bird, pair.id), mean.pecks = mean(pecks.per.hr))
peck.bird = merge(peck.bird,mean.peck.bird, by="pair.id")
# within-subject centring followed by adding back the grand mean so that p(r) effects are relocated relative to the grand mean
peck.bird$norm.pecks = (peck.bird$pecks.per.hr - peck.bird$mean.pecks)+mean(mean.peck.bird$mean.pecks)

# calculate how much the birds would have to increase their peck rate to compensate for p(r)
peck.prob$probability = factor(peck.prob$probability, levels = c("1", "0.4", "0.2"))
peck.prob$pecks.req = NA
peck.prob$pecks.req[1] = peck.prob$mean.pecks[1]
peck.prob$pecks.req[2] = peck.prob$mean.pecks[1]*2.5
peck.prob$pecks.req[3] = peck.prob$mean.pecks[1]*5

peck.bird$treatment[peck.bird$probability==1] = "FS"
peck.bird$treatment[peck.bird$probability==0.4] = "FIlow"
peck.bird$treatment[peck.bird$probability==0.2] = "FIhigh"
peck.bird$treatment = factor(peck.bird$treatment, levels = c("FS", "FIlow", "FIhigh"))


fig = ggplot(data=peck.bird, aes(x=treatment, y=norm.pecks)) +
  geom_boxplot(aes(fill=treatment)) +
  geom_point(data=peck.prob, aes(x=as.numeric(probability), y=pecks.req), shape = 18, size = 5) +
  guides(fill=FALSE) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato")) +
  scale_x_discrete(labels = c("FS" = "FS", "FIlow"=expression(paste(FI[low])), "FIhigh"=expression(paste(FI[high])))) +
  ylab("Peck rate (pecks/hour)") +
  xlab("") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=75, yend=75, size=.5) +
  annotate("text", x=1.5, y=77, label = "***", size=4) +
  annotate("segment", x=2, xend=3, y=80, yend=80, size=.5) +
  annotate("text", x=2.5, y=82, label = "***", size=4) +
  annotate("segment", x=1, xend=3, y=85, yend=85, size=.5) +
  annotate("text", x=2, y=87, label = "***", size=4)
fig
win.metafile("Exp 4 pecks per hr.wmf")
fig
dev.off()


peck.day$probability = relevel(peck.day$probability, ref = "1")
m = lmer(pecks.per.hr ~ probability + (1|pair/pair.id), data=peck.day)
summary(m)
confint(m)
anova(m) # As p(r) declines total pecks per day goes up

peck.day$probability = relevel(peck.day$probability, ref = "0.4")
m = lmer(pecks.per.hr ~ probability + (1|pair/pair.id), data=peck.day)
summary(m)
confint(m)

peck.day$probability = relevel(peck.day$probability, ref = "1")



#### Reinforcements earned: reinforced pecks per day ####

#Subset data to get reinforced trials only
f = subset(d,reinforcement=="reinforced")

# Total reinforcements per day
feed.d = summarise(group_by(f,pair.id,probability,day,pair), n=n(), crumb = mean(total_eaten))
feed.d$feeds.per.hr = feed.d$n/14.5

# first get the means feeds for each bird in each p(r) for the results table
feed.b = summarise(group_by(feed.d,pair, pair.id,probability), feeds = mean(feeds.per.hr, na.rm = TRUE))
feed.prob = summarise(group_by(feed.b, probability), mean.feeds = mean(feeds), sd.feeds = sd(feeds))
feed.prob$se = feed.prob$sd.feeds/sqrt(6)

# now calculate overall mean for each bird and merge this back into the above dataframe
mean.feed.b = summarise(group_by(feed.d, pair.id), mean.feeds = mean(feeds.per.hr))
feed.d = merge(feed.d,mean.feed.b, by="pair.id")
# within-subject centering followed by adding back the grand mean so that p(r) effects are relocated relative to the grand mean
feed.d$norm.feeds = (feed.d$feeds.per.hr - feed.b$mean.feeds)+mean(mean.feed.b$mean.feeds)



fig = ggplot(data=feed.d, aes(x=probability, y=norm.feeds)) +
  geom_boxplot(aes(fill=probability)) +
  guides(fill=FALSE) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato")) +
  scale_x_discrete(labels = c("1" = "FS", "0.4"=expression(paste(FI[low])), "0.2"=expression(paste(FI[high])))) +
  ylab("Reinforcement rate (reinforcements/hour)") +
  xlab("") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=44, yend=44, size=.5) +
  annotate("text", x=1.5, y=45, label = "***", size=4) +
  annotate("segment", x=2, xend=3, y=45, yend=45, size=.5) +
  annotate("text", x=2.5, y=46, label = "0.1 > p > 0.05", size=4) +
  annotate("segment", x=1, xend=3, y=47, yend=47, size=.5) +
  annotate("text", x=2, y=48, label = "***", size=4)
fig
win.metafile("Exp 4 feeds per hr.wmf")
fig
dev.off()


# model reinforcements per hour
feed.d$probability = relevel(feed.d$probability, ref = "1")
m = lmer(feeds.per.hr ~ probability + (1|pair/pair.id), data=feed.d)
summary(m)
confint(m)
anova(m) # As p(r) declines total reinforcements per day declines

feed.d$probability = relevel(feed.d$probability, ref = "0.4")
m = lmer(feeds.per.hr ~ probability + (1|pair/pair.id), data=feed.d)
summary(m)
confint(m)

feed.d$probability = relevel(feed.d$probability, ref = "1")




##### Amount eaten per reinforcement ####

feed.pair = summarise(group_by(feed.d,pair,day, probability), feeds.pair = sum(n, na.rm = TRUE), crumb.pair = mean(crumb, na.rm = T))
feed.pair$crumb.per.feed = feed.pair$crumb.pair/feed.pair$feeds.pair

eff.pair = summarise(group_by(feed.pair,pair, probability), eff.pair = mean(crumb.per.feed, na.rm = TRUE))
eff.prob = summarise(group_by(eff.pair, probability), eff = mean(eff.pair, na.rm = TRUE), sd = sd(eff.pair, na.rm = TRUE))
eff.prob$se = eff.prob$sd/sqrt(3)

# calculate the mean rate for each pair
mean.eff.pair = summarise(group_by(feed.pair,pair), mean.eff = mean(crumb.per.feed, na.rm = TRUE))
# now merge the mean rate for each pair back into the above dataframe
feed.pair = merge(feed.pair,mean.eff.pair, by="pair")
# within-subject centering followed by adding back the grand mean so that p(r) effects are relocated relative to the grand mean
feed.pair$norm.eff = (feed.pair$crumb.per.feed - feed.pair$mean.eff)+ mean(feed.pair$crumb.per.feed, na.rm = TRUE)

feed.pair$probability = factor(eff.pair$probability, levels = c("1", "0.4", "0.2"))


fig = ggplot(data=feed.pair, aes(x=probability, y=norm.eff)) +
  geom_boxplot(aes(fill=probability)) +
  guides(fill=FALSE) +
  scale_fill_manual(values=c("cyan", "tomato", "tomato")) +
  scale_x_discrete(labels = c("1" = "FS", "0.4"=expression(paste(FI[low])), "0.2"=expression(paste(FI[high])))) +
  ylab("Consumption rate (g/reinforcement)") +
  xlab("") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate("segment", x=1, xend=2, y=0.15, yend=0.15, size=.5) +
  annotate("text", x=1.5, y=0.155, label = "***", size=4) +
  annotate("segment", x=2, xend=3, y=0.16, yend=0.16, size=.5) +
  annotate("text", x=2.5, y=0.165, label = "0.1 > p > 0.05", size=4) +
  annotate("segment", x=1, xend=3, y=0.17, yend=0.17, size=.5) +
  annotate("text", x=2, y=0.175, label = "***", size=4)
fig
win.metafile("Exp 4 consumption per reinforcement.wmf")
fig
dev.off()

# model food eaten per reinforcement

feed.pair$probability = relevel(feed.pair$probability, ref = "1")
m = lmer(crumb.per.feed ~ probability + (1|pair), data=feed.pair)
summary(m)
confint(m)
anova(m) # As p(r) declines total efficiency goes up

feed.pair$probability = relevel(feed.pair$probability, ref = "0.4")
m = lmer(crumb.per.feed ~ probability + (1|pair), data=feed.pair)
summary(m)
confint(m)


