# Meta-analysis of data from FI studies

# This script uses aviary as the unit of replication

# Melissa Bateson
# version 2 written 4th March 2021 to read in a single data file and remove analyses not presented in the ms



library(dplyr)
library(metafor)
library(ggplot2)

rm(list=ls())


# read in the data file
da = read.csv("Meta-analysis data.csv")


#### Food consumption ####

f1a = da[da$variable=="food.eaten",]

f1a$abs.change = f1a$mean.FS-f1a$mean.FI
mean(f1a$abs.change)
f1a$perc.change = 100*f1a$abs.change/f1a$mean.FS
mean(f1a$perc.change)


# Fit a random effects model to the parameter estimates derived from the mixed models for effect if FI on amount eaten
m = rma.mv(yi = beta, V = se.beta^2, data = f1a, random = ~exp.aviary|exp)
summary(m)
confint(m)
forest(m, slab = f1a$label, xlab = "Effect of FI on daily food consumption (g)")

postscript(file="Consumption forest plot n8.ps", horizontal = FALSE, height = 4, pointsize = 14)
forest(m, slab = f1a$label, xlab = "Effect of FI on daily food consumption (g)")
dev.off()



# adding baseline mass and number of birds as moderators 
m = rma.mv(yi = beta, V = se.beta^2, data = f1a, random = ~exp.aviary|exp, mods = ~ baseline.mass + no.birds,
           control = list(step.min = 0.5))
summary(m)

# NB model does not converge with default control settings for the optimiser.
# changing the minimum step size from the default of 1.0 was necessary to make model converge.
# The number of iterations can be increased with iter.max (the default is 150 and it wasn't necessary to change this here).

# Note that there is no effect of no.birds
# percentage of heterogeneity explained by baseline mass and no.birds
(3.2000-1.9144)/3.2000 # 40.18% of heterogeneity explained by baseline mass and no.birds.


#### Dawn mass ####

m1a = da[da$variable=="mass.dawn",]

m1a$abs.change = m1a$mean.FS-m1a$mean.FI
mean(m1a$abs.change)
m1a$perc.change = 100*m1a$abs.change/m1a$mean.FS
mean(m1a$perc.change)

# Fit a multi-level random effects model to the parameter estimates derived from the mixed models
m = rma.mv(yi = beta, V = se.beta^2,  data = m1a, random = ~ exp.aviary|exp)
summary(m)
confint(m)

forest(m, slab = m1a$label, xlab = "Effect of FI on dawn mass (g)")

postscript(file="Dawn mass forest plot n8.ps", horizontal = FALSE, height = 4, pointsize = 14)
forest(m, slab = m1a$label, xlab = "Effect of food insecurity on dawn mass (g)")
dev.off()


# Add baseline mass and number of birds as moderators
m = rma.mv(yi = beta, V = se.beta^2,  data = m1a, random = ~ exp.aviary|exp, mods = ~ baseline.mass + no.birds)
summary(m)

# percent of heterogeneity explained by adding moderators
(0.9500-0.1722)/0.9500 # = 81.87%

# draw a graph of this
wi = 1/sqrt(m1a$se.beta^2) 
size = .5 + 5* (wi - min(wi))/(max(wi) - min(wi))

fig = ggplot(data = m1a, aes(x = baseline.mass, y = beta)) +
  geom_point(size = size, aes(shape = no.birds)) +
  geom_text(aes(label = exp), hjust = 0, nudge_x = 0.2) +
  geom_abline(aes(slope = -0.4516, intercept = 36.2362), linetype = "dashed", size = 1) +
  geom_abline(aes(slope = -0.4516, intercept = 36.2362-1.7595), size = 1) +
  geom_hline(yintercept = 0, linetype = "dotted") +
  ylab("Effect of food insecurity on dawn mass (g)") +
  xlab("Mean dawn mass during initial period of food security (g)") +
  scale_shape_discrete(name = "Competition") +
  ylim(-2.5,2.5) +
  xlim(71.5,81.75) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
        legend.position=c(0.1,0.1), legend.box.background = element_rect(colour = "black"),
        legend.background = element_blank())
fig

postscript(file="Dawn mass meta-regression.ps", horizontal = FALSE, height = 4, pointsize = 14)
fig
dev.off()





#### Dusk mass ####

m2a = da[da$variable=="mass.dusk",]

m2a$abs.change = m2a$mean.FS-m2a$mean.FI
mean(m2a$abs.change)
m2a$perc.change = 100*m2a$abs.change/m2a$mean.FS
mean(m2a$perc.change)


# Fit a random effects model to the parameter estimates derived from the mixed models
m = rma.mv(yi = beta, V = se.beta^2,  data = m2a, random = ~exp.aviary|exp)
summary(m)
confint(m)

forest(m, slab = m2a$label, xlab = "Effect of FI on dusk mass (g)")

postscript(file="Dusk mass forest plot n8.ps", horizontal = FALSE, height = 4, pointsize = 14)
forest(m, slab = m1a$label, xlab = "Effect of FI on dusk mass (g)")
dev.off()


# add baseline mass and number of birds as modifiers
m = rma.mv(yi = beta, V = se.beta^2, mods = ~ baseline.mass + no.birds,  data = m2a, random = ~exp.aviary|exp)
summary(m)
confint(m)

# percent of heterogeneity explained by adding moderators
(3.1421-0.7413)/3.1421 # = 76.41%

wi = 1/sqrt(m2a$se.beta^2) 
size = .5 + 5* (wi - min(wi))/(max(wi) - min(wi))

fig = ggplot(data = m2a, aes(x = baseline.mass, y = beta)) +
  geom_point(size = size, aes(shape = no.birds)) +
  geom_text(aes(label = exp), hjust = 0, nudge_x = 0.2) +
  geom_abline(aes(slope = -0.5049, intercept = 42.8497), linetype = "dashed", size = 1) +
  geom_abline(aes(slope = -0.5049, intercept = 42.8497-3.6018), size = 1) +
  geom_hline(yintercept = 0, linetype = "dotted") +
  ylab("Effect of food insecurity on dusk mass (g)") +
  xlab("Mean dawn mass during initial period of food security (g)") +
  scale_shape_discrete(name = "Competition") +
  ylim(-1,5) +
  xlim(72,84) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), 
        legend.position=c(0.1,0.1), legend.box.background = element_rect(colour = "black"),
        legend.background = element_blank())
fig

postscript(file="Dusk mass meta-regression.ps", horizontal = FALSE, height = 4, pointsize = 14)
fig
dev.off()



#### Efficiency ####


e1a = da[da$variable=="efficiency.dawn",]

e1a$abs.change = e1a$mean.FS-e1a$mean.FI
mean(e1a$abs.change)
e1a$perc.change = 100*e1a$abs.change/e1a$mean.FS
mean(e1a$perc.change)

# Fit a multi-level random effects model to the parameter estimates derived from the mixed models
m = rma.mv(yi = beta, V = se.beta^2, data = e1a, random = ~exp.aviary|exp)
summary(m)
forest(m, slab = e1a$label, xlab = "Effect of FI on efficiency (g bird/g food)")

postscript(file="Efficiency forest plot n8.ps", horizontal = FALSE, height = 4, pointsize = 14)
forest(m, slab = e1a$label, xlab = "Effect of FI on efficiency (g bird/g food)")
dev.off()



# add baseline mass and no.birds as modifiers
m = rma.mv(yi = beta, V = se.beta^2, mods = ~ baseline.mass + no.birds,  
           data = e1a, random = ~exp.aviary|exp, 
           control = list(optimizer="optim", optmethod="SANN", maxit = 100000))
summary(m)
confint(m)
# NB model did not converge with default settings for rma.mv.
# I had to change the optimiser from 'nlminb' to 'optim' and also change the method to "SANN"
# SANN is supposed to find values on very rough surfaces.
# I also increased the number of iterations from the default due to getting different results on each run
# increasing maxit to 100,000 solved this problem and gave stable results.

# calculate percentage of total heterogeneity accounted for by baseline mass
(0.1983-0.1588)/0.1983 # 19.92% of the residual heterogeneity in efficiency is explained by baseline mass.




#### comparing the summary effects with standardised betas ####

# This analysis is so that we can compare the size of the effect of FI on mass and efficiency

m = rma.mv(yi = standard.beta, V = standard.se.beta^2, data = f1a, random = ~exp.aviary|exp)
summary(m)

m = rma.mv(yi = standard.beta, V = standard.se.beta^2,  data = m1a, random = ~ exp.aviary|exp)
summary(m)
forest(m, slab = m1a$exp.aviary, xlab = "Difference in dawn mass under FI (g)")

m = rma.mv(yi = standard.beta, V = standard.se.beta^2,  data = m2a, random = ~exp.aviary|exp)
summary(m)

m = rma.mv(yi = standard.beta, V = standard.se.beta^2, data = e1a, random = ~exp.aviary|exp)
summary(m)




#### Behaviour analysis ####

r = da[da$variable=="prop.roost",]


r$abs.change = r$mean.FS-r$mean.FI
mean(r$abs.change)
r$perc.change = 100*r$abs.change/r$mean.FS
mean(r$perc.change)


# Fit a random effects model to the parameter estimates derived from the mixed models for effect if FI on proportion roosting
m = rma.mv(yi = beta, V = se.beta^2,  data = r, random = ~ aviary|exp)
summary(m)
forest(m, slab = r$label, xlab = "Effect of FI on roosting (arcsin square root of proportion)")

postscript(file="behaviour.forest.ps", horizontal = FALSE, height = 4, pointsize = 14)
forest(m, slab = r$label, xlab = "Effect of FI on roosting (arcsin square root of proportion)")
dev.off()


#### Guano analysis ####


g = da[da$variable=="energy.density",]

g$abs.change = g$mean.FS-g$mean.FI
mean(g$abs.change)
g$perc.change = 100*g$abs.change/g$mean.FS
mean(g$perc.change)

# Fit a random effects model to the parameter estimates derived from the mixed models for effect if FI on proportion roosting
m = rma.mv(yi = beta, V = se.beta^2,  data = g, random = ~ aviary|exp)
summary(m)
forest(m, slab = g$label, xlab = "Effect of FI on energy density of guano")

postscript(file="guano.forest.ps", horizontal = FALSE, height = 4, pointsize = 14)
forest(m, slab = g$label, xlab = "Effect of FI on energy density of guano")
dev.off()

